/*
 * This was automagically generated from mach-types!
 * Do NOT edit
 */

#ifndef __ASM_ARM_MACH_TYPE_H
#define __ASM_ARM_MACH_TYPE_H

#include <linux/config.h>

#ifndef __ASSEMBLY__
/* The type of machine we're running on */
extern unsigned int __machine_arch_type;
#endif

/* see arch/arm/kernel/arch.c for a description of these */
#define MACH_TYPE_EBSA110              0
#define MACH_TYPE_RISCPC               1
#define MACH_TYPE_NEXUSPCI             3
#define MACH_TYPE_EBSA285              4
#define MACH_TYPE_NETWINDER            5
#define MACH_TYPE_CATS                 6
#define MACH_TYPE_TBOX                 7
#define MACH_TYPE_CO285                8
#define MACH_TYPE_CLPS7110             9
#define MACH_TYPE_ARCHIMEDES           10
#define MACH_TYPE_A5K                  11
#define MACH_TYPE_ETOILE               12
#define MACH_TYPE_LACIE_NAS            13
#define MACH_TYPE_CLPS7500             14
#define MACH_TYPE_SHARK                15
#define MACH_TYPE_BRUTUS               16
#define MACH_TYPE_PERSONAL_SERVER      17
#define MACH_TYPE_ITSY                 18
#define MACH_TYPE_L7200                19
#define MACH_TYPE_PLEB                 20
#define MACH_TYPE_INTEGRATOR           21
#define MACH_TYPE_H3600                22
#define MACH_TYPE_IXP1200              23
#define MACH_TYPE_P720T                24
#define MACH_TYPE_ASSABET              25
#define MACH_TYPE_VICTOR               26
#define MACH_TYPE_LART                 27
#define MACH_TYPE_RANGER               28
#define MACH_TYPE_GRAPHICSCLIENT       29
#define MACH_TYPE_XP860                30
#define MACH_TYPE_CERF                 31
#define MACH_TYPE_NANOENGINE           32
#define MACH_TYPE_FPIC                 33
#define MACH_TYPE_EXTENEX1             34
#define MACH_TYPE_SHERMAN              35
#define MACH_TYPE_ACCELENT_SA          36
#define MACH_TYPE_ACCELENT_L7200       37
#define MACH_TYPE_NETPORT              38
#define MACH_TYPE_PANGOLIN             39
#define MACH_TYPE_YOPY                 40
#define MACH_TYPE_COOLIDGE             41
#define MACH_TYPE_HUW_WEBPANEL         42
#define MACH_TYPE_SPOTME               43
#define MACH_TYPE_FREEBIRD             44
#define MACH_TYPE_TI925                45
#define MACH_TYPE_RISCSTATION          46
#define MACH_TYPE_CAVY                 47
#define MACH_TYPE_JORNADA720           48
#define MACH_TYPE_OMNIMETER            49
#define MACH_TYPE_EDB7211              50
#define MACH_TYPE_CITYGO               51
#define MACH_TYPE_PFS168               52
#define MACH_TYPE_SPOT                 53
#define MACH_TYPE_FLEXANET             54
#define MACH_TYPE_WEBPAL               55
#define MACH_TYPE_LINPDA               56
#define MACH_TYPE_ANAKIN               57
#define MACH_TYPE_MVI                  58
#define MACH_TYPE_JUPITER              59
#define MACH_TYPE_PSIONW               60
#define MACH_TYPE_ALN                  61
#define MACH_TYPE_CAMELOT              62
#define MACH_TYPE_GDS2200              63
#define MACH_TYPE_PSION_SERIES7        64
#define MACH_TYPE_XFILE                65
#define MACH_TYPE_ACCELENT_EP9312      66
#define MACH_TYPE_IC200                67
#define MACH_TYPE_CREDITLART           68
#define MACH_TYPE_HTM                  69
#define MACH_TYPE_IQ80310              70
#define MACH_TYPE_FREEBOT              71
#define MACH_TYPE_ENTEL                72
#define MACH_TYPE_ENP3510              73
#define MACH_TYPE_TRIZEPS              74
#define MACH_TYPE_NESA                 75
#define MACH_TYPE_VENUS                76
#define MACH_TYPE_TARDIS               77
#define MACH_TYPE_MERCURY              78
#define MACH_TYPE_EMPEG                79
#define MACH_TYPE_I80200FCC            80
#define MACH_TYPE_ITT_CPB              81
#define MACH_TYPE_SVC                  82
#define MACH_TYPE_ALPHA2               84
#define MACH_TYPE_ALPHA1               85
#define MACH_TYPE_NETARM               86
#define MACH_TYPE_SIMPAD               87
#define MACH_TYPE_PDA1                 88
#define MACH_TYPE_LUBBOCK              89
#define MACH_TYPE_ANIKO                90
#define MACH_TYPE_CLEP7212             91
#define MACH_TYPE_CS89712              92
#define MACH_TYPE_WEARARM              93
#define MACH_TYPE_POSSIO_PX            94
#define MACH_TYPE_SIDEARM              95
#define MACH_TYPE_STORK                96
#define MACH_TYPE_SHANNON              97
#define MACH_TYPE_ACE                  98
#define MACH_TYPE_BALLYARM             99
#define MACH_TYPE_SIMPUTER             100
#define MACH_TYPE_NEXTERM              101
#define MACH_TYPE_SA1100_ELF           102
#define MACH_TYPE_GATOR                103
#define MACH_TYPE_GRANITE              104
#define MACH_TYPE_CONSUS               105
#define MACH_TYPE_AAED2000             106
#define MACH_TYPE_CDB89712             107
#define MACH_TYPE_GRAPHICSMASTER       108
#define MACH_TYPE_ADSBITSY             109
#define MACH_TYPE_PXA_IDP              110
#define MACH_TYPE_PLCE                 111
#define MACH_TYPE_PT_SYSTEM3           112
#define MACH_TYPE_MEDALB               113
#define MACH_TYPE_EAGLE                114
#define MACH_TYPE_DSC21                115
#define MACH_TYPE_DSC24                116
#define MACH_TYPE_TI5472               117
#define MACH_TYPE_AUTCPU12             118
#define MACH_TYPE_UENGINE              119
#define MACH_TYPE_BLUESTEM             120
#define MACH_TYPE_XINGU8               121
#define MACH_TYPE_BUSHSTB              122
#define MACH_TYPE_EPSILON1             123
#define MACH_TYPE_BALLOON              124
#define MACH_TYPE_PUPPY                125
#define MACH_TYPE_ELROY                126
#define MACH_TYPE_GMS720               127
#define MACH_TYPE_S24X                 128
#define MACH_TYPE_JTEL_CLEP7312        129
#define MACH_TYPE_CX821XX              130
#define MACH_TYPE_EDB7312              131
#define MACH_TYPE_BSA1110              132
#define MACH_TYPE_POWERPIN             133
#define MACH_TYPE_OPENARM              134
#define MACH_TYPE_WHITECHAPEL          135
#define MACH_TYPE_H3100                136
#define MACH_TYPE_H3800                137
#define MACH_TYPE_BLUE_V1              138
#define MACH_TYPE_PXA_CERF             139
#define MACH_TYPE_ARM7TEVB             140
#define MACH_TYPE_D7400                141
#define MACH_TYPE_PIRANHA              142
#define MACH_TYPE_SBCAMELOT            143
#define MACH_TYPE_KINGS                144
#define MACH_TYPE_SMDK2400             145
#define MACH_TYPE_COLLIE               146
#define MACH_TYPE_IDR                  147
#define MACH_TYPE_BADGE4               148
#define MACH_TYPE_WEBNET               149
#define MACH_TYPE_D7300                150
#define MACH_TYPE_CEP                  151
#define MACH_TYPE_FORTUNET             152
#define MACH_TYPE_VC547X               153
#define MACH_TYPE_FILEWALKER           154
#define MACH_TYPE_NETGATEWAY           155
#define MACH_TYPE_SYMBOL2800           156
#define MACH_TYPE_SUNS                 157
#define MACH_TYPE_FRODO                158
#define MACH_TYPE_MACH_TYTE_MS301      159
#define MACH_TYPE_MX1ADS               160
#define MACH_TYPE_H7201                161
#define MACH_TYPE_H7202                162
#define MACH_TYPE_AMICO                163
#define MACH_TYPE_IAM                  164
#define MACH_TYPE_TT530                165
#define MACH_TYPE_SAM2400              166
#define MACH_TYPE_JORNADA56X           167
#define MACH_TYPE_ACTIVE               168
#define MACH_TYPE_IQ80321              169
#define MACH_TYPE_WID                  170
#define MACH_TYPE_SABINAL              171
#define MACH_TYPE_IXP425_MATACUMBE     172
#define MACH_TYPE_MINIPRINT            173
#define MACH_TYPE_ADM510X              174
#define MACH_TYPE_SVS200               175
#define MACH_TYPE_ATG_TCU              176
#define MACH_TYPE_JORNADA820           177
#define MACH_TYPE_S3C44B0              178
#define MACH_TYPE_MARGIS2              179
#define MACH_TYPE_KS8695               180
#define MACH_TYPE_BRH                  181
#define MACH_TYPE_S3C2410              182
#define MACH_TYPE_POSSIO_PX30          183
#define MACH_TYPE_S3C2800              184
#define MACH_TYPE_FLEETWOOD            185
#define MACH_TYPE_OMAHA                186
#define MACH_TYPE_TA7                  187
#define MACH_TYPE_NOVA                 188
#define MACH_TYPE_HMK                  189
#define MACH_TYPE_KARO                 190
#define MACH_TYPE_FESTER               191
#define MACH_TYPE_GPI                  192
#define MACH_TYPE_SMDK2410             193
#define MACH_TYPE_I519                 194
#define MACH_TYPE_NEXIO                195
#define MACH_TYPE_BITBOX               196
#define MACH_TYPE_G200                 197
#define MACH_TYPE_GILL                 198
#define MACH_TYPE_PXA_MERCURY          199
#define MACH_TYPE_CEIVA                200
#define MACH_TYPE_FRET                 201
#define MACH_TYPE_EMAILPHONE           202
#define MACH_TYPE_H3900                203
#define MACH_TYPE_PXA1                 204
#define MACH_TYPE_KOAN369              205
#define MACH_TYPE_COGENT               206
#define MACH_TYPE_ESL_SIMPUTER         207
#define MACH_TYPE_ESL_SIMPUTER_CLR     208
#define MACH_TYPE_ESL_SIMPUTER_BW      209
#define MACH_TYPE_HHP_CRADLE           210
#define MACH_TYPE_HE500                211
#define MACH_TYPE_INHANDELF2           212
#define MACH_TYPE_INHANDFTIP           213
#define MACH_TYPE_DNP1110              214
#define MACH_TYPE_PNP1110              215
#define MACH_TYPE_CSB226               216
#define MACH_TYPE_ARNOLD               217
#define MACH_TYPE_PSIBOARD             218
#define MACH_TYPE_JZ8028               219
#define MACH_TYPE_H5400                220
#define MACH_TYPE_FORTE                221
#define MACH_TYPE_ACAM                 222
#define MACH_TYPE_ABOX                 223
#define MACH_TYPE_ATMEL                224
#define MACH_TYPE_SITSANG              225
#define MACH_TYPE_CPU1110LCDNET        226
#define MACH_TYPE_MPL_VCMA9            227
#define MACH_TYPE_OPUS_A1              228
#define MACH_TYPE_DAYTONA              229
#define MACH_TYPE_KILLBEAR             230
#define MACH_TYPE_YOHO                 231
#define MACH_TYPE_JASPER               232
#define MACH_TYPE_DSC25                233
#define MACH_TYPE_INNOVATOR            234
#define MACH_TYPE_RAMSES               235
#define MACH_TYPE_S28X                 236
#define MACH_TYPE_MPORT3               237
#define MACH_TYPE_PXA_EAGLE250         238
#define MACH_TYPE_PDB                  239
#define MACH_TYPE_BLUE_2G              240
#define MACH_TYPE_BLUEARCH             241
#define MACH_TYPE_IXMB2400             242
#define MACH_TYPE_IXMB2800             243
#define MACH_TYPE_EXPLORER             244
#define MACH_TYPE_IXDP425              245
#define MACH_TYPE_CHIMP                246
#define MACH_TYPE_STORK_NEST           247
#define MACH_TYPE_STORK_EGG            248
#define MACH_TYPE_WISMO                249
#define MACH_TYPE_EZLINX               250
#define MACH_TYPE_AT91RM9200           251
#define MACH_TYPE_ORION                252
#define MACH_TYPE_NEPTUNE              253
#define MACH_TYPE_HACKKIT              254
#define MACH_TYPE_PXA_WINS30           255
#define MACH_TYPE_LAVINNA              256
#define MACH_TYPE_PXA_UENGINE          257
#define MACH_TYPE_INNOKOM              258
#define MACH_TYPE_BMS                  259
#define MACH_TYPE_IXCDP1100            260
#define MACH_TYPE_PRPMC1100            261
#define MACH_TYPE_AT91RM9200DK         262
#define MACH_TYPE_ARMSTICK             263
#define MACH_TYPE_ARMONIE              264
#define MACH_TYPE_MPORT1               265
#define MACH_TYPE_S3C5410              266
#define MACH_TYPE_ZCP320A              267
#define MACH_TYPE_I_BOX                268
#define MACH_TYPE_STLC1502             269
#define MACH_TYPE_SIREN                270
#define MACH_TYPE_GREENLAKE            271
#define MACH_TYPE_ARGUS                272
#define MACH_TYPE_COMBADGE             273
#define MACH_TYPE_ROKEPXA              274
#define MACH_TYPE_CINTEGRATOR          275
#define MACH_TYPE_GUIDEA07             276
#define MACH_TYPE_TAT257               277
#define MACH_TYPE_IGP2425              278
#define MACH_TYPE_BLUEGRAMMA           279
#define MACH_TYPE_IPOD                 280
#define MACH_TYPE_ADSBITSYX            281
#define MACH_TYPE_TRIZEPS2             282
#define MACH_TYPE_VIPER                283
#define MACH_TYPE_ADSBITSYPLUS         284
#define MACH_TYPE_ADSAGC               285
#define MACH_TYPE_STP7312              286
#define MACH_TYPE_NX_PHNX              287
#define MACH_TYPE_WEP_EP250            288
#define MACH_TYPE_INHANDELF3           289
#define MACH_TYPE_ADI_COYOTE           290
#define MACH_TYPE_IYONIX               291
#define MACH_TYPE_DAMICAM_SA1110       292
#define MACH_TYPE_MEG03                293
#define MACH_TYPE_PXA_WHITECHAPEL      294
#define MACH_TYPE_NWSC                 295
#define MACH_TYPE_NWLARM               296
#define MACH_TYPE_IXP425_MGUARD        297
#define MACH_TYPE_PXA_NETDCU4          298
#define MACH_TYPE_IXDP2401             299
#define MACH_TYPE_IXDP2801             300
#define MACH_TYPE_ZODIAC               301
#define MACH_TYPE_ARMMODUL             302
#define MACH_TYPE_KETOP                303
#define MACH_TYPE_AV7200               304
#define MACH_TYPE_ARCH_TI925           305
#define MACH_TYPE_ACQ200               306
#define MACH_TYPE_PT_DAFIT             307
#define MACH_TYPE_IHBA                 308
#define MACH_TYPE_QUINQUE              309
#define MACH_TYPE_NIMBRAONE            310
#define MACH_TYPE_NIMBRA29X            311
#define MACH_TYPE_NIMBRA210            312
#define MACH_TYPE_HHP_D95XX            313
#define MACH_TYPE_LABARM               314
#define MACH_TYPE_M825XX               315
#define MACH_TYPE_M7100                316
#define MACH_TYPE_NIPC2                317
#define MACH_TYPE_FU7202               318
#define MACH_TYPE_ADSAGX               319
#define MACH_TYPE_PXA_POOH             320
#define MACH_TYPE_BANDON               321
#define MACH_TYPE_PCM7210              322
#define MACH_TYPE_NMS9200              323
#define MACH_TYPE_LOGODL               324
#define MACH_TYPE_M7140                325
#define MACH_TYPE_KOREBOT              326
#define MACH_TYPE_IQ31244              327
#define MACH_TYPE_KOAN393              328
#define MACH_TYPE_INHANDFTIP3          329
#define MACH_TYPE_GONZO                330
#define MACH_TYPE_BAST                 331
#define MACH_TYPE_SCANPASS             332
#define MACH_TYPE_EP7312_POOH          333
#define MACH_TYPE_TA7S                 334
#define MACH_TYPE_TA7V                 335
#define MACH_TYPE_ICARUS               336
#define MACH_TYPE_H1900                337
#define MACH_TYPE_GEMINI               338
#define MACH_TYPE_AXIM                 339
#define MACH_TYPE_AUDIOTRON            340
#define MACH_TYPE_H2200                341
#define MACH_TYPE_LOOX600              342
#define MACH_TYPE_NIOP                 343
#define MACH_TYPE_DM310                344
#define MACH_TYPE_SEEDPXA_C2           345
#define MACH_TYPE_IXP4XX_MGUARD_PCI    346
#define MACH_TYPE_H1940                347
#define MACH_TYPE_SCORPIO              348
#define MACH_TYPE_VIVA                 349
#define MACH_TYPE_PXA_XCARD            350
#define MACH_TYPE_CSB335               351
#define MACH_TYPE_IXRD425              352
#define MACH_TYPE_IQ80315              353
#define MACH_TYPE_NMP7312              354
#define MACH_TYPE_CX861XX              355
#define MACH_TYPE_ENP2611              356
#define MACH_TYPE_XDA                  357
#define MACH_TYPE_CSIR_IMS             358
#define MACH_TYPE_IXP421_DNAEETH       359
#define MACH_TYPE_POCKETSERV9200       360
#define MACH_TYPE_TOTO                 361
#define MACH_TYPE_S3C2440              362
#define MACH_TYPE_KS8695P              363
#define MACH_TYPE_SE4000               364
#define MACH_TYPE_QUADRICEPS           365
#define MACH_TYPE_BRONCO               366
#define MACH_TYPE_ESL_SOFCOMP          368
#define MACH_TYPE_S5C7375              369
#define MACH_TYPE_SPEARHEAD            370
#define MACH_TYPE_PANTERA              371
#define MACH_TYPE_PRAYOGLITE           372
#define MACH_TYPE_GUMSTIK              373
#define MACH_TYPE_RCUBE                374
#define MACH_TYPE_REA_OLV              375
#define MACH_TYPE_PXA_IPHONE           376
#define MACH_TYPE_S3C3410              377
#define MACH_TYPE_ESPD_4510B           378
#define MACH_TYPE_MP1X                 379
#define MACH_TYPE_AT91RM9200TB         380
#define MACH_TYPE_ADSVGX               381
#define MACH_TYPE_OMAP_H2              382
#define MACH_TYPE_PELEE                383
#define MACH_TYPE_E740                 384
#define MACH_TYPE_IQ80331              385
#define MACH_TYPE_VERSATILE_PB         387
#define MACH_TYPE_KEV7A400             388
#define MACH_TYPE_LPD7A400             389
#define MACH_TYPE_LPD7A404             390
#define MACH_TYPE_FUJITSU_CAMELOT      391
#define MACH_TYPE_JANUS2M              392
#define MACH_TYPE_EMBTF                393
#define MACH_TYPE_HPM                  394
#define MACH_TYPE_SMDK2410TK           395
#define MACH_TYPE_SMDK2410AJ           396
#define MACH_TYPE_STREETRACER          397
#define MACH_TYPE_EFRAME               398
#define MACH_TYPE_CSB337               399
#define MACH_TYPE_PXA_LARK             400
#define MACH_TYPE_PNP2110              401
#define MACH_TYPE_TCC72X               402
#define MACH_TYPE_ALTAIR               403
#define MACH_TYPE_KC3                  404
#define MACH_TYPE_SINTEFTD             405
#define MACH_TYPE_MAINSTONE            406
#define MACH_TYPE_ADAY4X               407
#define MACH_TYPE_LITE300              408
#define MACH_TYPE_S5C7376              409
#define MACH_TYPE_MT02                 410
#define MACH_TYPE_MPORT3S              411
#define MACH_TYPE_RA_ALPHA             412
#define MACH_TYPE_XCEP                 413
#define MACH_TYPE_ARCOM_MERCURY        414
#define MACH_TYPE_STARGATE             415
#define MACH_TYPE_ARMADILLOJ           416
#define MACH_TYPE_ELROY_JACK           417
#define MACH_TYPE_BACKEND              418
#define MACH_TYPE_S5LINBOX             419
#define MACH_TYPE_NOMADIK              420
#define MACH_TYPE_IA_CPU_9200          421
#define MACH_TYPE_AT91_BJA1            422
#define MACH_TYPE_CORGI                423
#define MACH_TYPE_POODLE               424
#define MACH_TYPE_TEN                  425
#define MACH_TYPE_ROVERP5P             426
#define MACH_TYPE_SC2700               427
#define MACH_TYPE_EX_EAGLE             428
#define MACH_TYPE_NX_PXA12             429
#define MACH_TYPE_NX_PXA5              430
#define MACH_TYPE_BLACKBOARD2          431
#define MACH_TYPE_I819                 432
#define MACH_TYPE_IXMB995E             433
#define MACH_TYPE_SKYRIDER             434
#define MACH_TYPE_SKYHAWK              435
#define MACH_TYPE_ENTERPRISE           436
#define MACH_TYPE_DEP2410              437
#define MACH_TYPE_ARMCORE              438
#define MACH_TYPE_HOBBIT               439
#define MACH_TYPE_H7210                440
#define MACH_TYPE_PXA_NETDCU5          441
#define MACH_TYPE_ACC                  442
#define MACH_TYPE_ESL_SARVA            443
#define MACH_TYPE_XM250                444
#define MACH_TYPE_T6TC1XB              445
#define MACH_TYPE_ESS710               446
#define MACH_TYPE_MX3ADS               447
#define MACH_TYPE_HIMALAYA             448
#define MACH_TYPE_BOLFENK              449
#define MACH_TYPE_AT91RM9200KR         450
#define MACH_TYPE_EDB9312              451
#define MACH_TYPE_OMAP_GENERIC         452
#define MACH_TYPE_AXIMX3               453
#define MACH_TYPE_EB67XDIP             454
#define MACH_TYPE_WEBTXS               455
#define MACH_TYPE_HAWK                 456
#define MACH_TYPE_CCAT91SBC001         457
#define MACH_TYPE_EXPRESSO             458
#define MACH_TYPE_H4000                459
#define MACH_TYPE_DINO                 460
#define MACH_TYPE_ML675K               461
#define MACH_TYPE_EDB9301              462
#define MACH_TYPE_EDB9315              463
#define MACH_TYPE_RECIVA_TT            464
#define MACH_TYPE_CSTCB01              465
#define MACH_TYPE_CSTCB1               466
#define MACH_TYPE_SHADWELL             467
#define MACH_TYPE_GOEPEL263            468
#define MACH_TYPE_ACQ100               469
#define MACH_TYPE_MX1FS2               470
#define MACH_TYPE_HIPTOP_G1            471
#define MACH_TYPE_SPARKY               472
#define MACH_TYPE_NS9750               473
#define MACH_TYPE_PHOENIX              474
#define MACH_TYPE_VR1000               475
#define MACH_TYPE_DEISTERPXA           476
#define MACH_TYPE_BCM1160              477
#define MACH_TYPE_PCM022               478
#define MACH_TYPE_ADSGCX               479
#define MACH_TYPE_DREADNAUGHT          480
#define MACH_TYPE_DM320                481
#define MACH_TYPE_MARKOV               482
#define MACH_TYPE_COS7A400             483
#define MACH_TYPE_MILANO               484
#define MACH_TYPE_UE9328               485
#define MACH_TYPE_UEX255               486
#define MACH_TYPE_UE2410               487
#define MACH_TYPE_A620                 488
#define MACH_TYPE_OCELOT               489
#define MACH_TYPE_CHEETAH              490
#define MACH_TYPE_OMAP_PERSEUS2        491
#define MACH_TYPE_ZVUE                 492
#define MACH_TYPE_ROVERP1              493
#define MACH_TYPE_ASIDIAL2             494
#define MACH_TYPE_S3C24A0              495
#define MACH_TYPE_E800                 496
#define MACH_TYPE_E750                 497
#define MACH_TYPE_S3C5500              498
#define MACH_TYPE_SMDK5500             499
#define MACH_TYPE_SIGNALSYNC           500
#define MACH_TYPE_NBC                  501
#define MACH_TYPE_ER4525               502
#define MACH_TYPE_NETBOOKPRO           503
#define MACH_TYPE_HW90200              504
#define MACH_TYPE_CONDOR               505
#define MACH_TYPE_CUP                  506
#define MACH_TYPE_KITE                 507
#define MACH_TYPE_SCB9328              508
#define MACH_TYPE_OMAP_H3              509
#define MACH_TYPE_OMAP_H4              510
#define MACH_TYPE_N10                  511
#define MACH_TYPE_MONTAJADE            512
#define MACH_TYPE_SG560                513
#define MACH_TYPE_DP1000               514
#define MACH_TYPE_OMAP_OSK             515
#define MACH_TYPE_RG100V3              516
#define MACH_TYPE_MX2ADS               517

#ifdef CONFIG_ARCH_EBSA110
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EBSA110
# endif
# define machine_is_ebsa110()	(machine_arch_type == MACH_TYPE_EBSA110)
#else
# define machine_is_ebsa110()	(0)
#endif

#ifdef CONFIG_ARCH_RPC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RISCPC
# endif
# define machine_is_riscpc()	(machine_arch_type == MACH_TYPE_RISCPC)
#else
# define machine_is_riscpc()	(0)
#endif

#ifdef CONFIG_ARCH_NEXUSPCI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NEXUSPCI
# endif
# define machine_is_nexuspci()	(machine_arch_type == MACH_TYPE_NEXUSPCI)
#else
# define machine_is_nexuspci()	(0)
#endif

#ifdef CONFIG_ARCH_EBSA285
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EBSA285
# endif
# define machine_is_ebsa285()	(machine_arch_type == MACH_TYPE_EBSA285)
#else
# define machine_is_ebsa285()	(0)
#endif

#ifdef CONFIG_ARCH_NETWINDER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NETWINDER
# endif
# define machine_is_netwinder()	(machine_arch_type == MACH_TYPE_NETWINDER)
#else
# define machine_is_netwinder()	(0)
#endif

#ifdef CONFIG_ARCH_CATS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CATS
# endif
# define machine_is_cats()	(machine_arch_type == MACH_TYPE_CATS)
#else
# define machine_is_cats()	(0)
#endif

#ifdef CONFIG_ARCH_TBOX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TBOX
# endif
# define machine_is_tbox()	(machine_arch_type == MACH_TYPE_TBOX)
#else
# define machine_is_tbox()	(0)
#endif

#ifdef CONFIG_ARCH_CO285
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CO285
# endif
# define machine_is_co285()	(machine_arch_type == MACH_TYPE_CO285)
#else
# define machine_is_co285()	(0)
#endif

#ifdef CONFIG_ARCH_CLPS7110
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CLPS7110
# endif
# define machine_is_clps7110()	(machine_arch_type == MACH_TYPE_CLPS7110)
#else
# define machine_is_clps7110()	(0)
#endif

#ifdef CONFIG_ARCH_ARC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARCHIMEDES
# endif
# define machine_is_archimedes()	(machine_arch_type == MACH_TYPE_ARCHIMEDES)
#else
# define machine_is_archimedes()	(0)
#endif

#ifdef CONFIG_ARCH_A5K
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_A5K
# endif
# define machine_is_a5k()	(machine_arch_type == MACH_TYPE_A5K)
#else
# define machine_is_a5k()	(0)
#endif

#ifdef CONFIG_ARCH_ETOILE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ETOILE
# endif
# define machine_is_etoile()	(machine_arch_type == MACH_TYPE_ETOILE)
#else
# define machine_is_etoile()	(0)
#endif

#ifdef CONFIG_ARCH_LACIE_NAS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LACIE_NAS
# endif
# define machine_is_lacie_nas()	(machine_arch_type == MACH_TYPE_LACIE_NAS)
#else
# define machine_is_lacie_nas()	(0)
#endif

#ifdef CONFIG_ARCH_CLPS7500
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CLPS7500
# endif
# define machine_is_clps7500()	(machine_arch_type == MACH_TYPE_CLPS7500)
#else
# define machine_is_clps7500()	(0)
#endif

#ifdef CONFIG_ARCH_SHARK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SHARK
# endif
# define machine_is_shark()	(machine_arch_type == MACH_TYPE_SHARK)
#else
# define machine_is_shark()	(0)
#endif

#ifdef CONFIG_SA1100_BRUTUS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BRUTUS
# endif
# define machine_is_brutus()	(machine_arch_type == MACH_TYPE_BRUTUS)
#else
# define machine_is_brutus()	(0)
#endif

#ifdef CONFIG_ARCH_PERSONAL_SERVER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PERSONAL_SERVER
# endif
# define machine_is_personal_server()	(machine_arch_type == MACH_TYPE_PERSONAL_SERVER)
#else
# define machine_is_personal_server()	(0)
#endif

#ifdef CONFIG_SA1100_ITSY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ITSY
# endif
# define machine_is_itsy()	(machine_arch_type == MACH_TYPE_ITSY)
#else
# define machine_is_itsy()	(0)
#endif

#ifdef CONFIG_ARCH_L7200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_L7200
# endif
# define machine_is_l7200()	(machine_arch_type == MACH_TYPE_L7200)
#else
# define machine_is_l7200()	(0)
#endif

#ifdef CONFIG_SA1100_PLEB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PLEB
# endif
# define machine_is_pleb()	(machine_arch_type == MACH_TYPE_PLEB)
#else
# define machine_is_pleb()	(0)
#endif

#ifdef CONFIG_ARCH_INTEGRATOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INTEGRATOR
# endif
# define machine_is_integrator()	(machine_arch_type == MACH_TYPE_INTEGRATOR)
#else
# define machine_is_integrator()	(0)
#endif

#ifdef CONFIG_SA1100_H3600
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H3600
# endif
# define machine_is_h3600()	(machine_arch_type == MACH_TYPE_H3600)
#else
# define machine_is_h3600()	(0)
#endif

#ifdef CONFIG_ARCH_IXP1200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXP1200
# endif
# define machine_is_ixp1200()	(machine_arch_type == MACH_TYPE_IXP1200)
#else
# define machine_is_ixp1200()	(0)
#endif

#ifdef CONFIG_ARCH_P720T
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_P720T
# endif
# define machine_is_p720t()	(machine_arch_type == MACH_TYPE_P720T)
#else
# define machine_is_p720t()	(0)
#endif

#ifdef CONFIG_SA1100_ASSABET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ASSABET
# endif
# define machine_is_assabet()	(machine_arch_type == MACH_TYPE_ASSABET)
#else
# define machine_is_assabet()	(0)
#endif

#ifdef CONFIG_SA1100_VICTOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VICTOR
# endif
# define machine_is_victor()	(machine_arch_type == MACH_TYPE_VICTOR)
#else
# define machine_is_victor()	(0)
#endif

#ifdef CONFIG_SA1100_LART
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LART
# endif
# define machine_is_lart()	(machine_arch_type == MACH_TYPE_LART)
#else
# define machine_is_lart()	(0)
#endif

#ifdef CONFIG_SA1100_RANGER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RANGER
# endif
# define machine_is_ranger()	(machine_arch_type == MACH_TYPE_RANGER)
#else
# define machine_is_ranger()	(0)
#endif

#ifdef CONFIG_SA1100_GRAPHICSCLIENT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GRAPHICSCLIENT
# endif
# define machine_is_graphicsclient()	(machine_arch_type == MACH_TYPE_GRAPHICSCLIENT)
#else
# define machine_is_graphicsclient()	(0)
#endif

#ifdef CONFIG_SA1100_XP860
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XP860
# endif
# define machine_is_xp860()	(machine_arch_type == MACH_TYPE_XP860)
#else
# define machine_is_xp860()	(0)
#endif

#ifdef CONFIG_SA1100_CERF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CERF
# endif
# define machine_is_cerf()	(machine_arch_type == MACH_TYPE_CERF)
#else
# define machine_is_cerf()	(0)
#endif

#ifdef CONFIG_SA1100_NANOENGINE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NANOENGINE
# endif
# define machine_is_nanoengine()	(machine_arch_type == MACH_TYPE_NANOENGINE)
#else
# define machine_is_nanoengine()	(0)
#endif

#ifdef CONFIG_SA1100_FPIC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FPIC
# endif
# define machine_is_fpic()	(machine_arch_type == MACH_TYPE_FPIC)
#else
# define machine_is_fpic()	(0)
#endif

#ifdef CONFIG_SA1100_EXTENEX1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EXTENEX1
# endif
# define machine_is_extenex1()	(machine_arch_type == MACH_TYPE_EXTENEX1)
#else
# define machine_is_extenex1()	(0)
#endif

#ifdef CONFIG_SA1100_SHERMAN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SHERMAN
# endif
# define machine_is_sherman()	(machine_arch_type == MACH_TYPE_SHERMAN)
#else
# define machine_is_sherman()	(0)
#endif

#ifdef CONFIG_SA1100_ACCELENT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACCELENT_SA
# endif
# define machine_is_accelent_sa()	(machine_arch_type == MACH_TYPE_ACCELENT_SA)
#else
# define machine_is_accelent_sa()	(0)
#endif

#ifdef CONFIG_ARCH_L7200_ACCELENT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACCELENT_L7200
# endif
# define machine_is_accelent_l7200()	(machine_arch_type == MACH_TYPE_ACCELENT_L7200)
#else
# define machine_is_accelent_l7200()	(0)
#endif

#ifdef CONFIG_SA1100_NETPORT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NETPORT
# endif
# define machine_is_netport()	(machine_arch_type == MACH_TYPE_NETPORT)
#else
# define machine_is_netport()	(0)
#endif

#ifdef CONFIG_SA1100_PANGOLIN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PANGOLIN
# endif
# define machine_is_pangolin()	(machine_arch_type == MACH_TYPE_PANGOLIN)
#else
# define machine_is_pangolin()	(0)
#endif

#ifdef CONFIG_SA1100_YOPY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_YOPY
# endif
# define machine_is_yopy()	(machine_arch_type == MACH_TYPE_YOPY)
#else
# define machine_is_yopy()	(0)
#endif

#ifdef CONFIG_SA1100_COOLIDGE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_COOLIDGE
# endif
# define machine_is_coolidge()	(machine_arch_type == MACH_TYPE_COOLIDGE)
#else
# define machine_is_coolidge()	(0)
#endif

#ifdef CONFIG_SA1100_HUW_WEBPANEL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HUW_WEBPANEL
# endif
# define machine_is_huw_webpanel()	(machine_arch_type == MACH_TYPE_HUW_WEBPANEL)
#else
# define machine_is_huw_webpanel()	(0)
#endif

#ifdef CONFIG_ARCH_SPOTME
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SPOTME
# endif
# define machine_is_spotme()	(machine_arch_type == MACH_TYPE_SPOTME)
#else
# define machine_is_spotme()	(0)
#endif

#ifdef CONFIG_ARCH_FREEBIRD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FREEBIRD
# endif
# define machine_is_freebird()	(machine_arch_type == MACH_TYPE_FREEBIRD)
#else
# define machine_is_freebird()	(0)
#endif

#ifdef CONFIG_ARCH_TI925
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TI925
# endif
# define machine_is_ti925()	(machine_arch_type == MACH_TYPE_TI925)
#else
# define machine_is_ti925()	(0)
#endif

#ifdef CONFIG_ARCH_RISCSTATION
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RISCSTATION
# endif
# define machine_is_riscstation()	(machine_arch_type == MACH_TYPE_RISCSTATION)
#else
# define machine_is_riscstation()	(0)
#endif

#ifdef CONFIG_SA1100_CAVY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CAVY
# endif
# define machine_is_cavy()	(machine_arch_type == MACH_TYPE_CAVY)
#else
# define machine_is_cavy()	(0)
#endif

#ifdef CONFIG_SA1100_JORNADA720
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JORNADA720
# endif
# define machine_is_jornada720()	(machine_arch_type == MACH_TYPE_JORNADA720)
#else
# define machine_is_jornada720()	(0)
#endif

#ifdef CONFIG_SA1100_OMNIMETER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMNIMETER
# endif
# define machine_is_omnimeter()	(machine_arch_type == MACH_TYPE_OMNIMETER)
#else
# define machine_is_omnimeter()	(0)
#endif

#ifdef CONFIG_ARCH_EDB7211
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB7211
# endif
# define machine_is_edb7211()	(machine_arch_type == MACH_TYPE_EDB7211)
#else
# define machine_is_edb7211()	(0)
#endif

#ifdef CONFIG_SA1100_CITYGO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CITYGO
# endif
# define machine_is_citygo()	(machine_arch_type == MACH_TYPE_CITYGO)
#else
# define machine_is_citygo()	(0)
#endif

#ifdef CONFIG_SA1100_PFS168
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PFS168
# endif
# define machine_is_pfs168()	(machine_arch_type == MACH_TYPE_PFS168)
#else
# define machine_is_pfs168()	(0)
#endif

#ifdef CONFIG_SA1100_SPOT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SPOT
# endif
# define machine_is_spot()	(machine_arch_type == MACH_TYPE_SPOT)
#else
# define machine_is_spot()	(0)
#endif

#ifdef CONFIG_SA1100_FLEXANET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FLEXANET
# endif
# define machine_is_flexanet()	(machine_arch_type == MACH_TYPE_FLEXANET)
#else
# define machine_is_flexanet()	(0)
#endif

#ifdef CONFIG_ARCH_WEBPAL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WEBPAL
# endif
# define machine_is_webpal()	(machine_arch_type == MACH_TYPE_WEBPAL)
#else
# define machine_is_webpal()	(0)
#endif

#ifdef CONFIG_SA1100_LINPDA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LINPDA
# endif
# define machine_is_linpda()	(machine_arch_type == MACH_TYPE_LINPDA)
#else
# define machine_is_linpda()	(0)
#endif

#ifdef CONFIG_ARCH_ANAKIN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ANAKIN
# endif
# define machine_is_anakin()	(machine_arch_type == MACH_TYPE_ANAKIN)
#else
# define machine_is_anakin()	(0)
#endif

#ifdef CONFIG_SA1100_MVI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MVI
# endif
# define machine_is_mvi()	(machine_arch_type == MACH_TYPE_MVI)
#else
# define machine_is_mvi()	(0)
#endif

#ifdef CONFIG_SA1100_JUPITER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JUPITER
# endif
# define machine_is_jupiter()	(machine_arch_type == MACH_TYPE_JUPITER)
#else
# define machine_is_jupiter()	(0)
#endif

#ifdef CONFIG_ARCH_PSIONW
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PSIONW
# endif
# define machine_is_psionw()	(machine_arch_type == MACH_TYPE_PSIONW)
#else
# define machine_is_psionw()	(0)
#endif

#ifdef CONFIG_SA1100_ALN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ALN
# endif
# define machine_is_aln()	(machine_arch_type == MACH_TYPE_ALN)
#else
# define machine_is_aln()	(0)
#endif

#ifdef CONFIG_ARCH_CAMELOT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CAMELOT
# endif
# define machine_is_epxa()	(machine_arch_type == MACH_TYPE_CAMELOT)
#else
# define machine_is_epxa()	(0)
#endif

#ifdef CONFIG_SA1100_GDS2200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GDS2200
# endif
# define machine_is_gds2200()	(machine_arch_type == MACH_TYPE_GDS2200)
#else
# define machine_is_gds2200()	(0)
#endif

#ifdef CONFIG_SA1100_PSION_SERIES7
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PSION_SERIES7
# endif
# define machine_is_psion_series7()	(machine_arch_type == MACH_TYPE_PSION_SERIES7)
#else
# define machine_is_psion_series7()	(0)
#endif

#ifdef CONFIG_SA1100_XFILE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XFILE
# endif
# define machine_is_xfile()	(machine_arch_type == MACH_TYPE_XFILE)
#else
# define machine_is_xfile()	(0)
#endif

#ifdef CONFIG_ARCH_ACCELENT_EP9312
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACCELENT_EP9312
# endif
# define machine_is_accelent_ep9312()	(machine_arch_type == MACH_TYPE_ACCELENT_EP9312)
#else
# define machine_is_accelent_ep9312()	(0)
#endif

#ifdef CONFIG_ARCH_IC200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IC200
# endif
# define machine_is_ic200()	(machine_arch_type == MACH_TYPE_IC200)
#else
# define machine_is_ic200()	(0)
#endif

#ifdef CONFIG_SA1100_CREDITLART
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CREDITLART
# endif
# define machine_is_creditlart()	(machine_arch_type == MACH_TYPE_CREDITLART)
#else
# define machine_is_creditlart()	(0)
#endif

#ifdef CONFIG_SA1100_HTM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HTM
# endif
# define machine_is_htm()	(machine_arch_type == MACH_TYPE_HTM)
#else
# define machine_is_htm()	(0)
#endif

#ifdef CONFIG_ARCH_IQ80310
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ80310
# endif
# define machine_is_iq80310()	(machine_arch_type == MACH_TYPE_IQ80310)
#else
# define machine_is_iq80310()	(0)
#endif

#ifdef CONFIG_SA1100_FREEBOT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FREEBOT
# endif
# define machine_is_freebot()	(machine_arch_type == MACH_TYPE_FREEBOT)
#else
# define machine_is_freebot()	(0)
#endif

#ifdef CONFIG_ARCH_ENTEL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ENTEL
# endif
# define machine_is_entel()	(machine_arch_type == MACH_TYPE_ENTEL)
#else
# define machine_is_entel()	(0)
#endif

#ifdef CONFIG_ARCH_ENP3510
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ENP3510
# endif
# define machine_is_enp3510()	(machine_arch_type == MACH_TYPE_ENP3510)
#else
# define machine_is_enp3510()	(0)
#endif

#ifdef CONFIG_SA1100_TRIZEPS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TRIZEPS
# endif
# define machine_is_trizeps()	(machine_arch_type == MACH_TYPE_TRIZEPS)
#else
# define machine_is_trizeps()	(0)
#endif

#ifdef CONFIG_SA1100_NESA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NESA
# endif
# define machine_is_nesa()	(machine_arch_type == MACH_TYPE_NESA)
#else
# define machine_is_nesa()	(0)
#endif

#ifdef CONFIG_ARCH_VENUS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VENUS
# endif
# define machine_is_venus()	(machine_arch_type == MACH_TYPE_VENUS)
#else
# define machine_is_venus()	(0)
#endif

#ifdef CONFIG_ARCH_TARDIS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TARDIS
# endif
# define machine_is_tardis()	(machine_arch_type == MACH_TYPE_TARDIS)
#else
# define machine_is_tardis()	(0)
#endif

#ifdef CONFIG_ARCH_MERCURY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MERCURY
# endif
# define machine_is_mercury()	(machine_arch_type == MACH_TYPE_MERCURY)
#else
# define machine_is_mercury()	(0)
#endif

#ifdef CONFIG_SA1100_EMPEG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EMPEG
# endif
# define machine_is_empeg()	(machine_arch_type == MACH_TYPE_EMPEG)
#else
# define machine_is_empeg()	(0)
#endif

#ifdef CONFIG_ARCH_I80200FCC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_I80200FCC
# endif
# define machine_is_adi_evb()	(machine_arch_type == MACH_TYPE_I80200FCC)
#else
# define machine_is_adi_evb()	(0)
#endif

#ifdef CONFIG_SA1100_ITT_CPB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ITT_CPB
# endif
# define machine_is_itt_cpb()	(machine_arch_type == MACH_TYPE_ITT_CPB)
#else
# define machine_is_itt_cpb()	(0)
#endif

#ifdef CONFIG_SA1100_SVC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SVC
# endif
# define machine_is_svc()	(machine_arch_type == MACH_TYPE_SVC)
#else
# define machine_is_svc()	(0)
#endif

#ifdef CONFIG_SA1100_ALPHA2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ALPHA2
# endif
# define machine_is_alpha2()	(machine_arch_type == MACH_TYPE_ALPHA2)
#else
# define machine_is_alpha2()	(0)
#endif

#ifdef CONFIG_SA1100_ALPHA1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ALPHA1
# endif
# define machine_is_alpha1()	(machine_arch_type == MACH_TYPE_ALPHA1)
#else
# define machine_is_alpha1()	(0)
#endif

#ifdef CONFIG_ARCH_NETARM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NETARM
# endif
# define machine_is_netarm()	(machine_arch_type == MACH_TYPE_NETARM)
#else
# define machine_is_netarm()	(0)
#endif

#ifdef CONFIG_SA1100_SIMPAD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SIMPAD
# endif
# define machine_is_simpad()	(machine_arch_type == MACH_TYPE_SIMPAD)
#else
# define machine_is_simpad()	(0)
#endif

#ifdef CONFIG_ARCH_PDA1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PDA1
# endif
# define machine_is_pda1()	(machine_arch_type == MACH_TYPE_PDA1)
#else
# define machine_is_pda1()	(0)
#endif

#ifdef CONFIG_ARCH_LUBBOCK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LUBBOCK
# endif
# define machine_is_lubbock()	(machine_arch_type == MACH_TYPE_LUBBOCK)
#else
# define machine_is_lubbock()	(0)
#endif

#ifdef CONFIG_ARCH_ANIKO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ANIKO
# endif
# define machine_is_aniko()	(machine_arch_type == MACH_TYPE_ANIKO)
#else
# define machine_is_aniko()	(0)
#endif

#ifdef CONFIG_ARCH_CLEP7212
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CLEP7212
# endif
# define machine_is_clep7212()	(machine_arch_type == MACH_TYPE_CLEP7212)
#else
# define machine_is_clep7212()	(0)
#endif

#ifdef CONFIG_ARCH_CS89712
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CS89712
# endif
# define machine_is_cs89712()	(machine_arch_type == MACH_TYPE_CS89712)
#else
# define machine_is_cs89712()	(0)
#endif

#ifdef CONFIG_SA1100_WEARARM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WEARARM
# endif
# define machine_is_weararm()	(machine_arch_type == MACH_TYPE_WEARARM)
#else
# define machine_is_weararm()	(0)
#endif

#ifdef CONFIG_SA1100_POSSIO_PX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_POSSIO_PX
# endif
# define machine_is_possio_px()	(machine_arch_type == MACH_TYPE_POSSIO_PX)
#else
# define machine_is_possio_px()	(0)
#endif

#ifdef CONFIG_SA1100_SIDEARM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SIDEARM
# endif
# define machine_is_sidearm()	(machine_arch_type == MACH_TYPE_SIDEARM)
#else
# define machine_is_sidearm()	(0)
#endif

#ifdef CONFIG_SA1100_STORK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STORK
# endif
# define machine_is_stork()	(machine_arch_type == MACH_TYPE_STORK)
#else
# define machine_is_stork()	(0)
#endif

#ifdef CONFIG_SA1100_SHANNON
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SHANNON
# endif
# define machine_is_shannon()	(machine_arch_type == MACH_TYPE_SHANNON)
#else
# define machine_is_shannon()	(0)
#endif

#ifdef CONFIG_ARCH_ACE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACE
# endif
# define machine_is_ace()	(machine_arch_type == MACH_TYPE_ACE)
#else
# define machine_is_ace()	(0)
#endif

#ifdef CONFIG_SA1100_BALLYARM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BALLYARM
# endif
# define machine_is_ballyarm()	(machine_arch_type == MACH_TYPE_BALLYARM)
#else
# define machine_is_ballyarm()	(0)
#endif

#ifdef CONFIG_SA1100_SIMPUTER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SIMPUTER
# endif
# define machine_is_simputer()	(machine_arch_type == MACH_TYPE_SIMPUTER)
#else
# define machine_is_simputer()	(0)
#endif

#ifdef CONFIG_SA1100_NEXTERM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NEXTERM
# endif
# define machine_is_nexterm()	(machine_arch_type == MACH_TYPE_NEXTERM)
#else
# define machine_is_nexterm()	(0)
#endif

#ifdef CONFIG_SA1100_SA1100_ELF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SA1100_ELF
# endif
# define machine_is_sa1100_elf()	(machine_arch_type == MACH_TYPE_SA1100_ELF)
#else
# define machine_is_sa1100_elf()	(0)
#endif

#ifdef CONFIG_SA1100_GATOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GATOR
# endif
# define machine_is_gator()	(machine_arch_type == MACH_TYPE_GATOR)
#else
# define machine_is_gator()	(0)
#endif

#ifdef CONFIG_ARCH_GRANITE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GRANITE
# endif
# define machine_is_granite()	(machine_arch_type == MACH_TYPE_GRANITE)
#else
# define machine_is_granite()	(0)
#endif

#ifdef CONFIG_SA1100_CONSUS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CONSUS
# endif
# define machine_is_consus()	(machine_arch_type == MACH_TYPE_CONSUS)
#else
# define machine_is_consus()	(0)
#endif

#ifdef CONFIG_ARCH_AAED2000
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AAED2000
# endif
# define machine_is_aaed2000()	(machine_arch_type == MACH_TYPE_AAED2000)
#else
# define machine_is_aaed2000()	(0)
#endif

#ifdef CONFIG_ARCH_CDB89712
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CDB89712
# endif
# define machine_is_cdb89712()	(machine_arch_type == MACH_TYPE_CDB89712)
#else
# define machine_is_cdb89712()	(0)
#endif

#ifdef CONFIG_SA1100_GRAPHICSMASTER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GRAPHICSMASTER
# endif
# define machine_is_graphicsmaster()	(machine_arch_type == MACH_TYPE_GRAPHICSMASTER)
#else
# define machine_is_graphicsmaster()	(0)
#endif

#ifdef CONFIG_SA1100_ADSBITSY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADSBITSY
# endif
# define machine_is_adsbitsy()	(machine_arch_type == MACH_TYPE_ADSBITSY)
#else
# define machine_is_adsbitsy()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_IDP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_IDP
# endif
# define machine_is_pxa_idp()	(machine_arch_type == MACH_TYPE_PXA_IDP)
#else
# define machine_is_pxa_idp()	(0)
#endif

#ifdef CONFIG_ARCH_PLCE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PLCE
# endif
# define machine_is_plce()	(machine_arch_type == MACH_TYPE_PLCE)
#else
# define machine_is_plce()	(0)
#endif

#ifdef CONFIG_SA1100_PT_SYSTEM3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PT_SYSTEM3
# endif
# define machine_is_pt_system3()	(machine_arch_type == MACH_TYPE_PT_SYSTEM3)
#else
# define machine_is_pt_system3()	(0)
#endif

#ifdef CONFIG_ARCH_MEDALB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MEDALB
# endif
# define machine_is_murphy()	(machine_arch_type == MACH_TYPE_MEDALB)
#else
# define machine_is_murphy()	(0)
#endif

#ifdef CONFIG_ARCH_EAGLE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EAGLE
# endif
# define machine_is_eagle()	(machine_arch_type == MACH_TYPE_EAGLE)
#else
# define machine_is_eagle()	(0)
#endif

#ifdef CONFIG_ARCH_DSC21
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DSC21
# endif
# define machine_is_dsc21()	(machine_arch_type == MACH_TYPE_DSC21)
#else
# define machine_is_dsc21()	(0)
#endif

#ifdef CONFIG_ARCH_DSC24
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DSC24
# endif
# define machine_is_dsc24()	(machine_arch_type == MACH_TYPE_DSC24)
#else
# define machine_is_dsc24()	(0)
#endif

#ifdef CONFIG_ARCH_TI5472
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TI5472
# endif
# define machine_is_ti5472()	(machine_arch_type == MACH_TYPE_TI5472)
#else
# define machine_is_ti5472()	(0)
#endif

#ifdef CONFIG_ARCH_AUTCPU12
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AUTCPU12
# endif
# define machine_is_autcpu12()	(machine_arch_type == MACH_TYPE_AUTCPU12)
#else
# define machine_is_autcpu12()	(0)
#endif

#ifdef CONFIG_ARCH_UENGINE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_UENGINE
# endif
# define machine_is_uengine()	(machine_arch_type == MACH_TYPE_UENGINE)
#else
# define machine_is_uengine()	(0)
#endif

#ifdef CONFIG_SA1100_BLUESTEM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BLUESTEM
# endif
# define machine_is_bluestem()	(machine_arch_type == MACH_TYPE_BLUESTEM)
#else
# define machine_is_bluestem()	(0)
#endif

#ifdef CONFIG_ARCH_XINGU8
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XINGU8
# endif
# define machine_is_xingu8()	(machine_arch_type == MACH_TYPE_XINGU8)
#else
# define machine_is_xingu8()	(0)
#endif

#ifdef CONFIG_ARCH_BUSHSTB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BUSHSTB
# endif
# define machine_is_bushstb()	(machine_arch_type == MACH_TYPE_BUSHSTB)
#else
# define machine_is_bushstb()	(0)
#endif

#ifdef CONFIG_SA1100_EPSILON1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EPSILON1
# endif
# define machine_is_epsilon1()	(machine_arch_type == MACH_TYPE_EPSILON1)
#else
# define machine_is_epsilon1()	(0)
#endif

#ifdef CONFIG_SA1100_BALLOON
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BALLOON
# endif
# define machine_is_balloon()	(machine_arch_type == MACH_TYPE_BALLOON)
#else
# define machine_is_balloon()	(0)
#endif

#ifdef CONFIG_ARCH_PUPPY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PUPPY
# endif
# define machine_is_puppy()	(machine_arch_type == MACH_TYPE_PUPPY)
#else
# define machine_is_puppy()	(0)
#endif

#ifdef CONFIG_SA1100_ELROY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ELROY
# endif
# define machine_is_elroy()	(machine_arch_type == MACH_TYPE_ELROY)
#else
# define machine_is_elroy()	(0)
#endif

#ifdef CONFIG_ARCH_GMS720
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GMS720
# endif
# define machine_is_gms720()	(machine_arch_type == MACH_TYPE_GMS720)
#else
# define machine_is_gms720()	(0)
#endif

#ifdef CONFIG_ARCH_S24X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S24X
# endif
# define machine_is_s24x()	(machine_arch_type == MACH_TYPE_S24X)
#else
# define machine_is_s24x()	(0)
#endif

#ifdef CONFIG_ARCH_JTEL_CLEP7312
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JTEL_CLEP7312
# endif
# define machine_is_jtel_clep7312()	(machine_arch_type == MACH_TYPE_JTEL_CLEP7312)
#else
# define machine_is_jtel_clep7312()	(0)
#endif

#ifdef CONFIG_ARCH_CX821XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CX821XX
# endif
# define machine_is_cx821xx()	(machine_arch_type == MACH_TYPE_CX821XX)
#else
# define machine_is_cx821xx()	(0)
#endif

#ifdef CONFIG_ARCH_EDB7312
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB7312
# endif
# define machine_is_edb7312()	(machine_arch_type == MACH_TYPE_EDB7312)
#else
# define machine_is_edb7312()	(0)
#endif

#ifdef CONFIG_SA1100_BSA1110
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BSA1110
# endif
# define machine_is_bsa1110()	(machine_arch_type == MACH_TYPE_BSA1110)
#else
# define machine_is_bsa1110()	(0)
#endif

#ifdef CONFIG_ARCH_POWERPIN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_POWERPIN
# endif
# define machine_is_powerpin()	(machine_arch_type == MACH_TYPE_POWERPIN)
#else
# define machine_is_powerpin()	(0)
#endif

#ifdef CONFIG_ARCH_OPENARM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OPENARM
# endif
# define machine_is_openarm()	(machine_arch_type == MACH_TYPE_OPENARM)
#else
# define machine_is_openarm()	(0)
#endif

#ifdef CONFIG_SA1100_WHITECHAPEL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WHITECHAPEL
# endif
# define machine_is_whitechapel()	(machine_arch_type == MACH_TYPE_WHITECHAPEL)
#else
# define machine_is_whitechapel()	(0)
#endif

#ifdef CONFIG_SA1100_H3100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H3100
# endif
# define machine_is_h3100()	(machine_arch_type == MACH_TYPE_H3100)
#else
# define machine_is_h3100()	(0)
#endif

#ifdef CONFIG_SA1100_H3800
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H3800
# endif
# define machine_is_h3800()	(machine_arch_type == MACH_TYPE_H3800)
#else
# define machine_is_h3800()	(0)
#endif

#ifdef CONFIG_ARCH_BLUE_V1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BLUE_V1
# endif
# define machine_is_blue_v1()	(machine_arch_type == MACH_TYPE_BLUE_V1)
#else
# define machine_is_blue_v1()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_CERF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_CERF
# endif
# define machine_is_pxa_cerf()	(machine_arch_type == MACH_TYPE_PXA_CERF)
#else
# define machine_is_pxa_cerf()	(0)
#endif

#ifdef CONFIG_ARCH_ARM7TEVB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARM7TEVB
# endif
# define machine_is_arm7tevb()	(machine_arch_type == MACH_TYPE_ARM7TEVB)
#else
# define machine_is_arm7tevb()	(0)
#endif

#ifdef CONFIG_SA1100_D7400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_D7400
# endif
# define machine_is_d7400()	(machine_arch_type == MACH_TYPE_D7400)
#else
# define machine_is_d7400()	(0)
#endif

#ifdef CONFIG_ARCH_PIRANHA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PIRANHA
# endif
# define machine_is_piranha()	(machine_arch_type == MACH_TYPE_PIRANHA)
#else
# define machine_is_piranha()	(0)
#endif

#ifdef CONFIG_SA1100_SBCAMELOT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SBCAMELOT
# endif
# define machine_is_sbcamelot()	(machine_arch_type == MACH_TYPE_SBCAMELOT)
#else
# define machine_is_sbcamelot()	(0)
#endif

#ifdef CONFIG_SA1100_KINGS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KINGS
# endif
# define machine_is_kings()	(machine_arch_type == MACH_TYPE_KINGS)
#else
# define machine_is_kings()	(0)
#endif

#ifdef CONFIG_ARCH_SMDK2400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK2400
# endif
# define machine_is_smdk2400()	(machine_arch_type == MACH_TYPE_SMDK2400)
#else
# define machine_is_smdk2400()	(0)
#endif

#ifdef CONFIG_SA1100_COLLIE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_COLLIE
# endif
# define machine_is_collie()	(machine_arch_type == MACH_TYPE_COLLIE)
#else
# define machine_is_collie()	(0)
#endif

#ifdef CONFIG_ARCH_IDR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IDR
# endif
# define machine_is_idr()	(machine_arch_type == MACH_TYPE_IDR)
#else
# define machine_is_idr()	(0)
#endif

#ifdef CONFIG_SA1100_BADGE4
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BADGE4
# endif
# define machine_is_badge4()	(machine_arch_type == MACH_TYPE_BADGE4)
#else
# define machine_is_badge4()	(0)
#endif

#ifdef CONFIG_ARCH_WEBNET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WEBNET
# endif
# define machine_is_webnet()	(machine_arch_type == MACH_TYPE_WEBNET)
#else
# define machine_is_webnet()	(0)
#endif

#ifdef CONFIG_SA1100_D7300
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_D7300
# endif
# define machine_is_d7300()	(machine_arch_type == MACH_TYPE_D7300)
#else
# define machine_is_d7300()	(0)
#endif

#ifdef CONFIG_SA1100_CEP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CEP
# endif
# define machine_is_cep()	(machine_arch_type == MACH_TYPE_CEP)
#else
# define machine_is_cep()	(0)
#endif

#ifdef CONFIG_ARCH_FORTUNET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FORTUNET
# endif
# define machine_is_fortunet()	(machine_arch_type == MACH_TYPE_FORTUNET)
#else
# define machine_is_fortunet()	(0)
#endif

#ifdef CONFIG_ARCH_VC547X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VC547X
# endif
# define machine_is_vc547x()	(machine_arch_type == MACH_TYPE_VC547X)
#else
# define machine_is_vc547x()	(0)
#endif

#ifdef CONFIG_SA1100_FILEWALKER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FILEWALKER
# endif
# define machine_is_filewalker()	(machine_arch_type == MACH_TYPE_FILEWALKER)
#else
# define machine_is_filewalker()	(0)
#endif

#ifdef CONFIG_SA1100_NETGATEWAY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NETGATEWAY
# endif
# define machine_is_netgateway()	(machine_arch_type == MACH_TYPE_NETGATEWAY)
#else
# define machine_is_netgateway()	(0)
#endif

#ifdef CONFIG_SA1100_SYMBOL2800
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SYMBOL2800
# endif
# define machine_is_symbol2800()	(machine_arch_type == MACH_TYPE_SYMBOL2800)
#else
# define machine_is_symbol2800()	(0)
#endif

#ifdef CONFIG_SA1100_SUNS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SUNS
# endif
# define machine_is_suns()	(machine_arch_type == MACH_TYPE_SUNS)
#else
# define machine_is_suns()	(0)
#endif

#ifdef CONFIG_SA1100_FRODO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FRODO
# endif
# define machine_is_frodo()	(machine_arch_type == MACH_TYPE_FRODO)
#else
# define machine_is_frodo()	(0)
#endif

#ifdef CONFIG_SA1100_MACH_TYTE_MS301
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MACH_TYTE_MS301
# endif
# define machine_is_ms301()	(machine_arch_type == MACH_TYPE_MACH_TYTE_MS301)
#else
# define machine_is_ms301()	(0)
#endif

#ifdef CONFIG_ARCH_MX1ADS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX1ADS
# endif
# define machine_is_mx1ads()	(machine_arch_type == MACH_TYPE_MX1ADS)
#else
# define machine_is_mx1ads()	(0)
#endif

#ifdef CONFIG_ARCH_H7201
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H7201
# endif
# define machine_is_h7201()	(machine_arch_type == MACH_TYPE_H7201)
#else
# define machine_is_h7201()	(0)
#endif

#ifdef CONFIG_ARCH_H7202
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H7202
# endif
# define machine_is_h7202()	(machine_arch_type == MACH_TYPE_H7202)
#else
# define machine_is_h7202()	(0)
#endif

#ifdef CONFIG_ARCH_AMICO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AMICO
# endif
# define machine_is_amico()	(machine_arch_type == MACH_TYPE_AMICO)
#else
# define machine_is_amico()	(0)
#endif

#ifdef CONFIG_SA1100_IAM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IAM
# endif
# define machine_is_iam()	(machine_arch_type == MACH_TYPE_IAM)
#else
# define machine_is_iam()	(0)
#endif

#ifdef CONFIG_SA1100_TT530
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TT530
# endif
# define machine_is_tt530()	(machine_arch_type == MACH_TYPE_TT530)
#else
# define machine_is_tt530()	(0)
#endif

#ifdef CONFIG_ARCH_SAM2400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SAM2400
# endif
# define machine_is_sam2400()	(machine_arch_type == MACH_TYPE_SAM2400)
#else
# define machine_is_sam2400()	(0)
#endif

#ifdef CONFIG_SA1100_JORNADA56X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JORNADA56X
# endif
# define machine_is_jornada56x()	(machine_arch_type == MACH_TYPE_JORNADA56X)
#else
# define machine_is_jornada56x()	(0)
#endif

#ifdef CONFIG_SA1100_ACTIVE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACTIVE
# endif
# define machine_is_active()	(machine_arch_type == MACH_TYPE_ACTIVE)
#else
# define machine_is_active()	(0)
#endif

#ifdef CONFIG_ARCH_IQ80321
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ80321
# endif
# define machine_is_iq80321()	(machine_arch_type == MACH_TYPE_IQ80321)
#else
# define machine_is_iq80321()	(0)
#endif

#ifdef CONFIG_SA1100_WID
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WID
# endif
# define machine_is_wid()	(machine_arch_type == MACH_TYPE_WID)
#else
# define machine_is_wid()	(0)
#endif

#ifdef CONFIG_ARCH_SABINAL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SABINAL
# endif
# define machine_is_sabinal()	(machine_arch_type == MACH_TYPE_SABINAL)
#else
# define machine_is_sabinal()	(0)
#endif

#ifdef CONFIG_ARCH_IXP425_MATACUMBE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXP425_MATACUMBE
# endif
# define machine_is_ixp425_matacumbe()	(machine_arch_type == MACH_TYPE_IXP425_MATACUMBE)
#else
# define machine_is_ixp425_matacumbe()	(0)
#endif

#ifdef CONFIG_SA1100_MINIPRINT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MINIPRINT
# endif
# define machine_is_miniprint()	(machine_arch_type == MACH_TYPE_MINIPRINT)
#else
# define machine_is_miniprint()	(0)
#endif

#ifdef CONFIG_ARCH_ADM510X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADM510X
# endif
# define machine_is_adm510x()	(machine_arch_type == MACH_TYPE_ADM510X)
#else
# define machine_is_adm510x()	(0)
#endif

#ifdef CONFIG_SA1100_SVS200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SVS200
# endif
# define machine_is_svs200()	(machine_arch_type == MACH_TYPE_SVS200)
#else
# define machine_is_svs200()	(0)
#endif

#ifdef CONFIG_ARCH_ATG_TCU
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ATG_TCU
# endif
# define machine_is_atg_tcu()	(machine_arch_type == MACH_TYPE_ATG_TCU)
#else
# define machine_is_atg_tcu()	(0)
#endif

#ifdef CONFIG_SA1100_JORNADA820
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JORNADA820
# endif
# define machine_is_jornada820()	(machine_arch_type == MACH_TYPE_JORNADA820)
#else
# define machine_is_jornada820()	(0)
#endif

#ifdef CONFIG_ARCH_S3C44B0
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C44B0
# endif
# define machine_is_s3c44b0()	(machine_arch_type == MACH_TYPE_S3C44B0)
#else
# define machine_is_s3c44b0()	(0)
#endif

#ifdef CONFIG_ARCH_MARGIS2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MARGIS2
# endif
# define machine_is_margis2()	(machine_arch_type == MACH_TYPE_MARGIS2)
#else
# define machine_is_margis2()	(0)
#endif

#ifdef CONFIG_ARCH_KS8695
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KS8695
# endif
# define machine_is_ks8695()	(machine_arch_type == MACH_TYPE_KS8695)
#else
# define machine_is_ks8695()	(0)
#endif

#ifdef CONFIG_ARCH_BRH
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BRH
# endif
# define machine_is_brh()	(machine_arch_type == MACH_TYPE_BRH)
#else
# define machine_is_brh()	(0)
#endif

#ifdef CONFIG_ARCH_S3C2410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C2410
# endif
# define machine_is_s3c2410()	(machine_arch_type == MACH_TYPE_S3C2410)
#else
# define machine_is_s3c2410()	(0)
#endif

#ifdef CONFIG_ARCH_POSSIO_PX30
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_POSSIO_PX30
# endif
# define machine_is_possio_px30()	(machine_arch_type == MACH_TYPE_POSSIO_PX30)
#else
# define machine_is_possio_px30()	(0)
#endif

#ifdef CONFIG_ARCH_S3C2800
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C2800
# endif
# define machine_is_s3c2800()	(machine_arch_type == MACH_TYPE_S3C2800)
#else
# define machine_is_s3c2800()	(0)
#endif

#ifdef CONFIG_SA1100_FLEETWOOD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FLEETWOOD
# endif
# define machine_is_fleetwood()	(machine_arch_type == MACH_TYPE_FLEETWOOD)
#else
# define machine_is_fleetwood()	(0)
#endif

#ifdef CONFIG_ARCH_OMAHA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAHA
# endif
# define machine_is_omaha()	(machine_arch_type == MACH_TYPE_OMAHA)
#else
# define machine_is_omaha()	(0)
#endif

#ifdef CONFIG_ARCH_TA7
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TA7
# endif
# define machine_is_ta7()	(machine_arch_type == MACH_TYPE_TA7)
#else
# define machine_is_ta7()	(0)
#endif

#ifdef CONFIG_SA1100_NOVA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOVA
# endif
# define machine_is_nova()	(machine_arch_type == MACH_TYPE_NOVA)
#else
# define machine_is_nova()	(0)
#endif

#ifdef CONFIG_ARCH_HMK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HMK
# endif
# define machine_is_hmk()	(machine_arch_type == MACH_TYPE_HMK)
#else
# define machine_is_hmk()	(0)
#endif

#ifdef CONFIG_ARCH_KARO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KARO
# endif
# define machine_is_karo()	(machine_arch_type == MACH_TYPE_KARO)
#else
# define machine_is_karo()	(0)
#endif

#ifdef CONFIG_SA1100_FESTER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FESTER
# endif
# define machine_is_fester()	(machine_arch_type == MACH_TYPE_FESTER)
#else
# define machine_is_fester()	(0)
#endif

#ifdef CONFIG_ARCH_GPI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GPI
# endif
# define machine_is_gpi()	(machine_arch_type == MACH_TYPE_GPI)
#else
# define machine_is_gpi()	(0)
#endif

#ifdef CONFIG_ARCH_SMDK2410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK2410
# endif
# define machine_is_smdk2410()	(machine_arch_type == MACH_TYPE_SMDK2410)
#else
# define machine_is_smdk2410()	(0)
#endif

#ifdef CONFIG_ARCH_I519
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_I519
# endif
# define machine_is_i519()	(machine_arch_type == MACH_TYPE_I519)
#else
# define machine_is_i519()	(0)
#endif

#ifdef CONFIG_SA1100_NEXIO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NEXIO
# endif
# define machine_is_nexio()	(machine_arch_type == MACH_TYPE_NEXIO)
#else
# define machine_is_nexio()	(0)
#endif

#ifdef CONFIG_SA1100_BITBOX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BITBOX
# endif
# define machine_is_bitbox()	(machine_arch_type == MACH_TYPE_BITBOX)
#else
# define machine_is_bitbox()	(0)
#endif

#ifdef CONFIG_SA1100_G200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_G200
# endif
# define machine_is_g200()	(machine_arch_type == MACH_TYPE_G200)
#else
# define machine_is_g200()	(0)
#endif

#ifdef CONFIG_SA1100_GILL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GILL
# endif
# define machine_is_gill()	(machine_arch_type == MACH_TYPE_GILL)
#else
# define machine_is_gill()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_MERCURY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_MERCURY
# endif
# define machine_is_pxa_mercury()	(machine_arch_type == MACH_TYPE_PXA_MERCURY)
#else
# define machine_is_pxa_mercury()	(0)
#endif

#ifdef CONFIG_ARCH_CEIVA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CEIVA
# endif
# define machine_is_ceiva()	(machine_arch_type == MACH_TYPE_CEIVA)
#else
# define machine_is_ceiva()	(0)
#endif

#ifdef CONFIG_SA1100_FRET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FRET
# endif
# define machine_is_fret()	(machine_arch_type == MACH_TYPE_FRET)
#else
# define machine_is_fret()	(0)
#endif

#ifdef CONFIG_SA1100_EMAILPHONE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EMAILPHONE
# endif
# define machine_is_emailphone()	(machine_arch_type == MACH_TYPE_EMAILPHONE)
#else
# define machine_is_emailphone()	(0)
#endif

#ifdef CONFIG_ARCH_H3900
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H3900
# endif
# define machine_is_h3900()	(machine_arch_type == MACH_TYPE_H3900)
#else
# define machine_is_h3900()	(0)
#endif

#ifdef CONFIG_ARCH_PXA1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA1
# endif
# define machine_is_pxa1()	(machine_arch_type == MACH_TYPE_PXA1)
#else
# define machine_is_pxa1()	(0)
#endif

#ifdef CONFIG_SA1100_KOAN369
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KOAN369
# endif
# define machine_is_koan369()	(machine_arch_type == MACH_TYPE_KOAN369)
#else
# define machine_is_koan369()	(0)
#endif

#ifdef CONFIG_ARCH_COGENT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_COGENT
# endif
# define machine_is_cogent()	(machine_arch_type == MACH_TYPE_COGENT)
#else
# define machine_is_cogent()	(0)
#endif

#ifdef CONFIG_ARCH_ESL_SIMPUTER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ESL_SIMPUTER
# endif
# define machine_is_esl_simputer()	(machine_arch_type == MACH_TYPE_ESL_SIMPUTER)
#else
# define machine_is_esl_simputer()	(0)
#endif

#ifdef CONFIG_ARCH_ESL_SIMPUTER_CLR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ESL_SIMPUTER_CLR
# endif
# define machine_is_esl_simputer_clr()	(machine_arch_type == MACH_TYPE_ESL_SIMPUTER_CLR)
#else
# define machine_is_esl_simputer_clr()	(0)
#endif

#ifdef CONFIG_ARCH_ESL_SIMPUTER_BW
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ESL_SIMPUTER_BW
# endif
# define machine_is_esl_simputer_bw()	(machine_arch_type == MACH_TYPE_ESL_SIMPUTER_BW)
#else
# define machine_is_esl_simputer_bw()	(0)
#endif

#ifdef CONFIG_ARCH_HHP_CRADLE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HHP_CRADLE
# endif
# define machine_is_hhp_cradle()	(machine_arch_type == MACH_TYPE_HHP_CRADLE)
#else
# define machine_is_hhp_cradle()	(0)
#endif

#ifdef CONFIG_ARCH_HE500
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HE500
# endif
# define machine_is_he500()	(machine_arch_type == MACH_TYPE_HE500)
#else
# define machine_is_he500()	(0)
#endif

#ifdef CONFIG_SA1100_INHANDELF2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INHANDELF2
# endif
# define machine_is_inhandelf2()	(machine_arch_type == MACH_TYPE_INHANDELF2)
#else
# define machine_is_inhandelf2()	(0)
#endif

#ifdef CONFIG_SA1100_INHANDFTIP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INHANDFTIP
# endif
# define machine_is_inhandftip()	(machine_arch_type == MACH_TYPE_INHANDFTIP)
#else
# define machine_is_inhandftip()	(0)
#endif

#ifdef CONFIG_SA1100_DNP1110
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DNP1110
# endif
# define machine_is_dnp1110()	(machine_arch_type == MACH_TYPE_DNP1110)
#else
# define machine_is_dnp1110()	(0)
#endif

#ifdef CONFIG_SA1100_PNP1110
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PNP1110
# endif
# define machine_is_pnp1110()	(machine_arch_type == MACH_TYPE_PNP1110)
#else
# define machine_is_pnp1110()	(0)
#endif

#ifdef CONFIG_ARCH_CSB226
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CSB226
# endif
# define machine_is_csb226()	(machine_arch_type == MACH_TYPE_CSB226)
#else
# define machine_is_csb226()	(0)
#endif

#ifdef CONFIG_SA1100_ARNOLD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARNOLD
# endif
# define machine_is_arnold()	(machine_arch_type == MACH_TYPE_ARNOLD)
#else
# define machine_is_arnold()	(0)
#endif

#ifdef CONFIG_SA1100_PSIBOARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PSIBOARD
# endif
# define machine_is_psiboard()	(machine_arch_type == MACH_TYPE_PSIBOARD)
#else
# define machine_is_psiboard()	(0)
#endif

#ifdef CONFIG_ARCH_JZ8028
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JZ8028
# endif
# define machine_is_jz8028()	(machine_arch_type == MACH_TYPE_JZ8028)
#else
# define machine_is_jz8028()	(0)
#endif

#ifdef CONFIG_ARCH_H5400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H5400
# endif
# define machine_is_h5400()	(machine_arch_type == MACH_TYPE_H5400)
#else
# define machine_is_h5400()	(0)
#endif

#ifdef CONFIG_SA1100_FORTE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FORTE
# endif
# define machine_is_forte()	(machine_arch_type == MACH_TYPE_FORTE)
#else
# define machine_is_forte()	(0)
#endif

#ifdef CONFIG_SA1100_ACAM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACAM
# endif
# define machine_is_acam()	(machine_arch_type == MACH_TYPE_ACAM)
#else
# define machine_is_acam()	(0)
#endif

#ifdef CONFIG_SA1100_ABOX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ABOX
# endif
# define machine_is_abox()	(machine_arch_type == MACH_TYPE_ABOX)
#else
# define machine_is_abox()	(0)
#endif

#ifdef CONFIG_ARCH_ATMEL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ATMEL
# endif
# define machine_is_atmel()	(machine_arch_type == MACH_TYPE_ATMEL)
#else
# define machine_is_atmel()	(0)
#endif

#ifdef CONFIG_ARCH_SITSANG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SITSANG
# endif
# define machine_is_sitsang()	(machine_arch_type == MACH_TYPE_SITSANG)
#else
# define machine_is_sitsang()	(0)
#endif

#ifdef CONFIG_SA1100_CPU1110LCDNET
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CPU1110LCDNET
# endif
# define machine_is_cpu1110lcdnet()	(machine_arch_type == MACH_TYPE_CPU1110LCDNET)
#else
# define machine_is_cpu1110lcdnet()	(0)
#endif

#ifdef CONFIG_ARCH_MPL_VCMA9
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MPL_VCMA9
# endif
# define machine_is_mpl_vcma9()	(machine_arch_type == MACH_TYPE_MPL_VCMA9)
#else
# define machine_is_mpl_vcma9()	(0)
#endif

#ifdef CONFIG_ARCH_OPUS_A1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OPUS_A1
# endif
# define machine_is_opus_a1()	(machine_arch_type == MACH_TYPE_OPUS_A1)
#else
# define machine_is_opus_a1()	(0)
#endif

#ifdef CONFIG_ARCH_DAYTONA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DAYTONA
# endif
# define machine_is_daytona()	(machine_arch_type == MACH_TYPE_DAYTONA)
#else
# define machine_is_daytona()	(0)
#endif

#ifdef CONFIG_SA1100_KILLBEAR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KILLBEAR
# endif
# define machine_is_killbear()	(machine_arch_type == MACH_TYPE_KILLBEAR)
#else
# define machine_is_killbear()	(0)
#endif

#ifdef CONFIG_ARCH_YOHO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_YOHO
# endif
# define machine_is_yoho()	(machine_arch_type == MACH_TYPE_YOHO)
#else
# define machine_is_yoho()	(0)
#endif

#ifdef CONFIG_ARCH_JASPER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JASPER
# endif
# define machine_is_jasper()	(machine_arch_type == MACH_TYPE_JASPER)
#else
# define machine_is_jasper()	(0)
#endif

#ifdef CONFIG_ARCH_DSC25
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DSC25
# endif
# define machine_is_dsc25()	(machine_arch_type == MACH_TYPE_DSC25)
#else
# define machine_is_dsc25()	(0)
#endif

#ifdef CONFIG_ARCH_INNOVATOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INNOVATOR
# endif
# define machine_is_innovator()	(machine_arch_type == MACH_TYPE_INNOVATOR)
#else
# define machine_is_innovator()	(0)
#endif

#ifdef CONFIG_ARCH_RAMSES
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RAMSES
# endif
# define machine_is_ramses()	(machine_arch_type == MACH_TYPE_RAMSES)
#else
# define machine_is_ramses()	(0)
#endif

#ifdef CONFIG_ARCH_S28X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S28X
# endif
# define machine_is_s28x()	(machine_arch_type == MACH_TYPE_S28X)
#else
# define machine_is_s28x()	(0)
#endif

#ifdef CONFIG_ARCH_MPORT3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MPORT3
# endif
# define machine_is_mport3()	(machine_arch_type == MACH_TYPE_MPORT3)
#else
# define machine_is_mport3()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_EAGLE250
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_EAGLE250
# endif
# define machine_is_pxa_eagle250()	(machine_arch_type == MACH_TYPE_PXA_EAGLE250)
#else
# define machine_is_pxa_eagle250()	(0)
#endif

#ifdef CONFIG_ARCH_PDB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PDB
# endif
# define machine_is_pdb()	(machine_arch_type == MACH_TYPE_PDB)
#else
# define machine_is_pdb()	(0)
#endif

#ifdef CONFIG_SA1100_BLUE_2G
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BLUE_2G
# endif
# define machine_is_blue_2g()	(machine_arch_type == MACH_TYPE_BLUE_2G)
#else
# define machine_is_blue_2g()	(0)
#endif

#ifdef CONFIG_SA1100_BLUEARCH
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BLUEARCH
# endif
# define machine_is_bluearch()	(machine_arch_type == MACH_TYPE_BLUEARCH)
#else
# define machine_is_bluearch()	(0)
#endif

#ifdef CONFIG_ARCH_IXMB2400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXMB2400
# endif
# define machine_is_ixdp2400()	(machine_arch_type == MACH_TYPE_IXMB2400)
#else
# define machine_is_ixdp2400()	(0)
#endif

#ifdef CONFIG_ARCH_IXMB2800
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXMB2800
# endif
# define machine_is_ixdp2800()	(machine_arch_type == MACH_TYPE_IXMB2800)
#else
# define machine_is_ixdp2800()	(0)
#endif

#ifdef CONFIG_SA1100_EXPLORER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EXPLORER
# endif
# define machine_is_explorer()	(machine_arch_type == MACH_TYPE_EXPLORER)
#else
# define machine_is_explorer()	(0)
#endif

#ifdef CONFIG_ARCH_IXDP425
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP425
# endif
# define machine_is_ixdp425()	(machine_arch_type == MACH_TYPE_IXDP425)
#else
# define machine_is_ixdp425()	(0)
#endif

#ifdef CONFIG_ARCH_CHIMP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CHIMP
# endif
# define machine_is_chimp()	(machine_arch_type == MACH_TYPE_CHIMP)
#else
# define machine_is_chimp()	(0)
#endif

#ifdef CONFIG_ARCH_STORK_NEST
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STORK_NEST
# endif
# define machine_is_stork_nest()	(machine_arch_type == MACH_TYPE_STORK_NEST)
#else
# define machine_is_stork_nest()	(0)
#endif

#ifdef CONFIG_ARCH_STORK_EGG
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STORK_EGG
# endif
# define machine_is_stork_egg()	(machine_arch_type == MACH_TYPE_STORK_EGG)
#else
# define machine_is_stork_egg()	(0)
#endif

#ifdef CONFIG_SA1100_WISMO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WISMO
# endif
# define machine_is_wismo()	(machine_arch_type == MACH_TYPE_WISMO)
#else
# define machine_is_wismo()	(0)
#endif

#ifdef CONFIG_ARCH_EZLINX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EZLINX
# endif
# define machine_is_ezlinx()	(machine_arch_type == MACH_TYPE_EZLINX)
#else
# define machine_is_ezlinx()	(0)
#endif

#ifdef CONFIG_ARCH_AT91RM9200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91RM9200
# endif
# define machine_is_at91rm9200()	(machine_arch_type == MACH_TYPE_AT91RM9200)
#else
# define machine_is_at91rm9200()	(0)
#endif

#ifdef CONFIG_ARCH_ORION
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ORION
# endif
# define machine_is_orion()	(machine_arch_type == MACH_TYPE_ORION)
#else
# define machine_is_orion()	(0)
#endif

#ifdef CONFIG_ARCH_NEPTUNE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NEPTUNE
# endif
# define machine_is_neptune()	(machine_arch_type == MACH_TYPE_NEPTUNE)
#else
# define machine_is_neptune()	(0)
#endif

#ifdef CONFIG_SA1100_HACKKIT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HACKKIT
# endif
# define machine_is_hackkit()	(machine_arch_type == MACH_TYPE_HACKKIT)
#else
# define machine_is_hackkit()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_WINS30
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_WINS30
# endif
# define machine_is_pxa_wins30()	(machine_arch_type == MACH_TYPE_PXA_WINS30)
#else
# define machine_is_pxa_wins30()	(0)
#endif

#ifdef CONFIG_SA1100_LAVINNA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LAVINNA
# endif
# define machine_is_lavinna()	(machine_arch_type == MACH_TYPE_LAVINNA)
#else
# define machine_is_lavinna()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_UENGINE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_UENGINE
# endif
# define machine_is_pxa_uengine()	(machine_arch_type == MACH_TYPE_PXA_UENGINE)
#else
# define machine_is_pxa_uengine()	(0)
#endif

#ifdef CONFIG_ARCH_INNOKOM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INNOKOM
# endif
# define machine_is_innokom()	(machine_arch_type == MACH_TYPE_INNOKOM)
#else
# define machine_is_innokom()	(0)
#endif

#ifdef CONFIG_ARCH_BMS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BMS
# endif
# define machine_is_bms()	(machine_arch_type == MACH_TYPE_BMS)
#else
# define machine_is_bms()	(0)
#endif

#ifdef CONFIG_ARCH_IXCDP1100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXCDP1100
# endif
# define machine_is_ixcdp1100()	(machine_arch_type == MACH_TYPE_IXCDP1100)
#else
# define machine_is_ixcdp1100()	(0)
#endif

#ifdef CONFIG_ARCH_PRPMC1100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PRPMC1100
# endif
# define machine_is_prpmc1100()	(machine_arch_type == MACH_TYPE_PRPMC1100)
#else
# define machine_is_prpmc1100()	(0)
#endif

#ifdef CONFIG_ARCH_AT91RM9200DK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91RM9200DK
# endif
# define machine_is_at91rm9200dk()	(machine_arch_type == MACH_TYPE_AT91RM9200DK)
#else
# define machine_is_at91rm9200dk()	(0)
#endif

#ifdef CONFIG_ARCH_ARMSTICK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARMSTICK
# endif
# define machine_is_armstick()	(machine_arch_type == MACH_TYPE_ARMSTICK)
#else
# define machine_is_armstick()	(0)
#endif

#ifdef CONFIG_ARCH_ARMONIE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARMONIE
# endif
# define machine_is_armonie()	(machine_arch_type == MACH_TYPE_ARMONIE)
#else
# define machine_is_armonie()	(0)
#endif

#ifdef CONFIG_ARCH_MPORT1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MPORT1
# endif
# define machine_is_mport1()	(machine_arch_type == MACH_TYPE_MPORT1)
#else
# define machine_is_mport1()	(0)
#endif

#ifdef CONFIG_ARCH_S3C5410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C5410
# endif
# define machine_is_s3c5410()	(machine_arch_type == MACH_TYPE_S3C5410)
#else
# define machine_is_s3c5410()	(0)
#endif

#ifdef CONFIG_ARCH_ZCP320A
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ZCP320A
# endif
# define machine_is_zcp320a()	(machine_arch_type == MACH_TYPE_ZCP320A)
#else
# define machine_is_zcp320a()	(0)
#endif

#ifdef CONFIG_ARCH_I_BOX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_I_BOX
# endif
# define machine_is_i_box()	(machine_arch_type == MACH_TYPE_I_BOX)
#else
# define machine_is_i_box()	(0)
#endif

#ifdef CONFIG_ARCH_STLC1502
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STLC1502
# endif
# define machine_is_stlc1502()	(machine_arch_type == MACH_TYPE_STLC1502)
#else
# define machine_is_stlc1502()	(0)
#endif

#ifdef CONFIG_ARCH_SIREN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SIREN
# endif
# define machine_is_siren()	(machine_arch_type == MACH_TYPE_SIREN)
#else
# define machine_is_siren()	(0)
#endif

#ifdef CONFIG_ARCH_GREENLAKE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GREENLAKE
# endif
# define machine_is_greenlake()	(machine_arch_type == MACH_TYPE_GREENLAKE)
#else
# define machine_is_greenlake()	(0)
#endif

#ifdef CONFIG_ARCH_ARGUS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARGUS
# endif
# define machine_is_argus()	(machine_arch_type == MACH_TYPE_ARGUS)
#else
# define machine_is_argus()	(0)
#endif

#ifdef CONFIG_SA1100_COMBADGE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_COMBADGE
# endif
# define machine_is_combadge()	(machine_arch_type == MACH_TYPE_COMBADGE)
#else
# define machine_is_combadge()	(0)
#endif

#ifdef CONFIG_ARCH_ROKEPXA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ROKEPXA
# endif
# define machine_is_rokepxa()	(machine_arch_type == MACH_TYPE_ROKEPXA)
#else
# define machine_is_rokepxa()	(0)
#endif

#ifdef CONFIG_ARCH_CINTEGRATOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CINTEGRATOR
# endif
# define machine_is_cintegrator()	(machine_arch_type == MACH_TYPE_CINTEGRATOR)
#else
# define machine_is_cintegrator()	(0)
#endif

#ifdef CONFIG_ARCH_GUIDEA07
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GUIDEA07
# endif
# define machine_is_guidea07()	(machine_arch_type == MACH_TYPE_GUIDEA07)
#else
# define machine_is_guidea07()	(0)
#endif

#ifdef CONFIG_ARCH_TAT257
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TAT257
# endif
# define machine_is_tat257()	(machine_arch_type == MACH_TYPE_TAT257)
#else
# define machine_is_tat257()	(0)
#endif

#ifdef CONFIG_ARCH_IGP2425
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IGP2425
# endif
# define machine_is_igp2425()	(machine_arch_type == MACH_TYPE_IGP2425)
#else
# define machine_is_igp2425()	(0)
#endif

#ifdef CONFIG_ARCH_BLUEGRAMMA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BLUEGRAMMA
# endif
# define machine_is_bluegrama()	(machine_arch_type == MACH_TYPE_BLUEGRAMMA)
#else
# define machine_is_bluegrama()	(0)
#endif

#ifdef CONFIG_ARCH_IPOD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IPOD
# endif
# define machine_is_ipod()	(machine_arch_type == MACH_TYPE_IPOD)
#else
# define machine_is_ipod()	(0)
#endif

#ifdef CONFIG_ARCH_ADSBITSYX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADSBITSYX
# endif
# define machine_is_adsbitsyx()	(machine_arch_type == MACH_TYPE_ADSBITSYX)
#else
# define machine_is_adsbitsyx()	(0)
#endif

#ifdef CONFIG_ARCH_TRIZEPS2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TRIZEPS2
# endif
# define machine_is_trizeps2()	(machine_arch_type == MACH_TYPE_TRIZEPS2)
#else
# define machine_is_trizeps2()	(0)
#endif

#ifdef CONFIG_ARCH_VIPER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VIPER
# endif
# define machine_is_viper()	(machine_arch_type == MACH_TYPE_VIPER)
#else
# define machine_is_viper()	(0)
#endif

#ifdef CONFIG_SA1100_ADSBITSYPLUS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADSBITSYPLUS
# endif
# define machine_is_adsbitsyplus()	(machine_arch_type == MACH_TYPE_ADSBITSYPLUS)
#else
# define machine_is_adsbitsyplus()	(0)
#endif

#ifdef CONFIG_SA1100_ADSAGC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADSAGC
# endif
# define machine_is_adsagc()	(machine_arch_type == MACH_TYPE_ADSAGC)
#else
# define machine_is_adsagc()	(0)
#endif

#ifdef CONFIG_ARCH_STP7312
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STP7312
# endif
# define machine_is_stp7312()	(machine_arch_type == MACH_TYPE_STP7312)
#else
# define machine_is_stp7312()	(0)
#endif

#ifdef CONFIG_MACH_NX_PHNX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NX_PHNX
# endif
# define machine_is_nx_phnx()	(machine_arch_type == MACH_TYPE_NX_PHNX)
#else
# define machine_is_nx_phnx()	(0)
#endif

#ifdef CONFIG_ARCH_WEP_EP250
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WEP_EP250
# endif
# define machine_is_wep_ep250()	(machine_arch_type == MACH_TYPE_WEP_EP250)
#else
# define machine_is_wep_ep250()	(0)
#endif

#ifdef CONFIG_ARCH_INHANDELF3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INHANDELF3
# endif
# define machine_is_inhandelf3()	(machine_arch_type == MACH_TYPE_INHANDELF3)
#else
# define machine_is_inhandelf3()	(0)
#endif

#ifdef CONFIG_ARCH_ADI_COYOTE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADI_COYOTE
# endif
# define machine_is_adi_coyote()	(machine_arch_type == MACH_TYPE_ADI_COYOTE)
#else
# define machine_is_adi_coyote()	(0)
#endif

#ifdef CONFIG_ARCH_IYONIX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IYONIX
# endif
# define machine_is_iyonix()	(machine_arch_type == MACH_TYPE_IYONIX)
#else
# define machine_is_iyonix()	(0)
#endif

#ifdef CONFIG_ARCH_DAMICAM_SA1110
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DAMICAM_SA1110
# endif
# define machine_is_damicam1()	(machine_arch_type == MACH_TYPE_DAMICAM_SA1110)
#else
# define machine_is_damicam1()	(0)
#endif

#ifdef CONFIG_ARCH_MEG03
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MEG03
# endif
# define machine_is_meg03()	(machine_arch_type == MACH_TYPE_MEG03)
#else
# define machine_is_meg03()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_WHITECHAPEL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_WHITECHAPEL
# endif
# define machine_is_pxa_whitechapel()	(machine_arch_type == MACH_TYPE_PXA_WHITECHAPEL)
#else
# define machine_is_pxa_whitechapel()	(0)
#endif

#ifdef CONFIG_ARCH_NWSC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NWSC
# endif
# define machine_is_nwsc()	(machine_arch_type == MACH_TYPE_NWSC)
#else
# define machine_is_nwsc()	(0)
#endif

#ifdef CONFIG_ARCH_NWLARM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NWLARM
# endif
# define machine_is_nwlarm()	(machine_arch_type == MACH_TYPE_NWLARM)
#else
# define machine_is_nwlarm()	(0)
#endif

#ifdef CONFIG_ARCH_IXP425_MGUARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXP425_MGUARD
# endif
# define machine_is_ixp425_mguard()	(machine_arch_type == MACH_TYPE_IXP425_MGUARD)
#else
# define machine_is_ixp425_mguard()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_NETDCU4
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_NETDCU4
# endif
# define machine_is_pxa_netdcu4()	(machine_arch_type == MACH_TYPE_PXA_NETDCU4)
#else
# define machine_is_pxa_netdcu4()	(0)
#endif

#ifdef CONFIG_ARCH_IXDP2401
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP2401
# endif
# define machine_is_ixdp2401()	(machine_arch_type == MACH_TYPE_IXDP2401)
#else
# define machine_is_ixdp2401()	(0)
#endif

#ifdef CONFIG_ARCH_IXDP2801
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXDP2801
# endif
# define machine_is_ixdp2801()	(machine_arch_type == MACH_TYPE_IXDP2801)
#else
# define machine_is_ixdp2801()	(0)
#endif

#ifdef CONFIG_ARCH_ZODIAC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ZODIAC
# endif
# define machine_is_zodiac()	(machine_arch_type == MACH_TYPE_ZODIAC)
#else
# define machine_is_zodiac()	(0)
#endif

#ifdef CONFIG_ARCH_ARMMODUL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARMMODUL
# endif
# define machine_is_armmodul()	(machine_arch_type == MACH_TYPE_ARMMODUL)
#else
# define machine_is_armmodul()	(0)
#endif

#ifdef CONFIG_SA1100_KETOP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KETOP
# endif
# define machine_is_ketop()	(machine_arch_type == MACH_TYPE_KETOP)
#else
# define machine_is_ketop()	(0)
#endif

#ifdef CONFIG_ARCH_AV7200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AV7200
# endif
# define machine_is_av7200()	(machine_arch_type == MACH_TYPE_AV7200)
#else
# define machine_is_av7200()	(0)
#endif

#ifdef CONFIG_ARCH_ARCH_TI925
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARCH_TI925
# endif
# define machine_is_arch_ti925()	(machine_arch_type == MACH_TYPE_ARCH_TI925)
#else
# define machine_is_arch_ti925()	(0)
#endif

#ifdef CONFIG_ARCH_ACQ200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACQ200
# endif
# define machine_is_acq200()	(machine_arch_type == MACH_TYPE_ACQ200)
#else
# define machine_is_acq200()	(0)
#endif

#ifdef CONFIG_SA1100_PT_DAFIT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PT_DAFIT
# endif
# define machine_is_pt_dafit()	(machine_arch_type == MACH_TYPE_PT_DAFIT)
#else
# define machine_is_pt_dafit()	(0)
#endif

#ifdef CONFIG_ARCH_IHBA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IHBA
# endif
# define machine_is_ihba()	(machine_arch_type == MACH_TYPE_IHBA)
#else
# define machine_is_ihba()	(0)
#endif

#ifdef CONFIG_ARCH_QUINQUE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_QUINQUE
# endif
# define machine_is_quinque()	(machine_arch_type == MACH_TYPE_QUINQUE)
#else
# define machine_is_quinque()	(0)
#endif

#ifdef CONFIG_ARCH_NIMBRAONE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NIMBRAONE
# endif
# define machine_is_nimbraone()	(machine_arch_type == MACH_TYPE_NIMBRAONE)
#else
# define machine_is_nimbraone()	(0)
#endif

#ifdef CONFIG_ARCH_NIMBRA29X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NIMBRA29X
# endif
# define machine_is_nimbra29x()	(machine_arch_type == MACH_TYPE_NIMBRA29X)
#else
# define machine_is_nimbra29x()	(0)
#endif

#ifdef CONFIG_ARCH_NIMBRA210
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NIMBRA210
# endif
# define machine_is_nimbra210()	(machine_arch_type == MACH_TYPE_NIMBRA210)
#else
# define machine_is_nimbra210()	(0)
#endif

#ifdef CONFIG_ARCH_HHP_D95XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HHP_D95XX
# endif
# define machine_is_hhp_d95xx()	(machine_arch_type == MACH_TYPE_HHP_D95XX)
#else
# define machine_is_hhp_d95xx()	(0)
#endif

#ifdef CONFIG_ARCH_LABARM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LABARM
# endif
# define machine_is_labarm()	(machine_arch_type == MACH_TYPE_LABARM)
#else
# define machine_is_labarm()	(0)
#endif

#ifdef CONFIG_ARCH_M825XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_M825XX
# endif
# define machine_is_m825xx()	(machine_arch_type == MACH_TYPE_M825XX)
#else
# define machine_is_m825xx()	(0)
#endif

#ifdef CONFIG_SA1100_M7100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_M7100
# endif
# define machine_is_m7100()	(machine_arch_type == MACH_TYPE_M7100)
#else
# define machine_is_m7100()	(0)
#endif

#ifdef CONFIG_ARCH_NIPC2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NIPC2
# endif
# define machine_is_nipc2()	(machine_arch_type == MACH_TYPE_NIPC2)
#else
# define machine_is_nipc2()	(0)
#endif

#ifdef CONFIG_ARCH_FU7202
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FU7202
# endif
# define machine_is_fu7202()	(machine_arch_type == MACH_TYPE_FU7202)
#else
# define machine_is_fu7202()	(0)
#endif

#ifdef CONFIG_ARCH_ADSAGX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADSAGX
# endif
# define machine_is_adsagx()	(machine_arch_type == MACH_TYPE_ADSAGX)
#else
# define machine_is_adsagx()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_POOH
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_POOH
# endif
# define machine_is_pxa_pooh()	(machine_arch_type == MACH_TYPE_PXA_POOH)
#else
# define machine_is_pxa_pooh()	(0)
#endif

#ifdef CONFIG_ARCH_BANDON
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BANDON
# endif
# define machine_is_bandon()	(machine_arch_type == MACH_TYPE_BANDON)
#else
# define machine_is_bandon()	(0)
#endif

#ifdef CONFIG_ARCH_PCM7210
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PCM7210
# endif
# define machine_is_pcm7210()	(machine_arch_type == MACH_TYPE_PCM7210)
#else
# define machine_is_pcm7210()	(0)
#endif

#ifdef CONFIG_ARCH_NMS9200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NMS9200
# endif
# define machine_is_nms9200()	(machine_arch_type == MACH_TYPE_NMS9200)
#else
# define machine_is_nms9200()	(0)
#endif

#ifdef CONFIG_ARCH_LOGODL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LOGODL
# endif
# define machine_is_logodl()	(machine_arch_type == MACH_TYPE_LOGODL)
#else
# define machine_is_logodl()	(0)
#endif

#ifdef CONFIG_SA1100_M7140
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_M7140
# endif
# define machine_is_m7140()	(machine_arch_type == MACH_TYPE_M7140)
#else
# define machine_is_m7140()	(0)
#endif

#ifdef CONFIG_ARCH_KOREBOT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KOREBOT
# endif
# define machine_is_korebot()	(machine_arch_type == MACH_TYPE_KOREBOT)
#else
# define machine_is_korebot()	(0)
#endif

#ifdef CONFIG_ARCH_IQ31244
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ31244
# endif
# define machine_is_iq31244()	(machine_arch_type == MACH_TYPE_IQ31244)
#else
# define machine_is_iq31244()	(0)
#endif

#ifdef CONFIG_SA1100_KOAN393
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KOAN393
# endif
# define machine_is_koan393()	(machine_arch_type == MACH_TYPE_KOAN393)
#else
# define machine_is_koan393()	(0)
#endif

#ifdef CONFIG_ARCH_INHANDFTIP3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_INHANDFTIP3
# endif
# define machine_is_inhandftip3()	(machine_arch_type == MACH_TYPE_INHANDFTIP3)
#else
# define machine_is_inhandftip3()	(0)
#endif

#ifdef CONFIG_ARCH_GONZO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GONZO
# endif
# define machine_is_gonzo()	(machine_arch_type == MACH_TYPE_GONZO)
#else
# define machine_is_gonzo()	(0)
#endif

#ifdef CONFIG_ARCH_BAST
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BAST
# endif
# define machine_is_bast()	(machine_arch_type == MACH_TYPE_BAST)
#else
# define machine_is_bast()	(0)
#endif

#ifdef CONFIG_ARCH_SCANPASS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SCANPASS
# endif
# define machine_is_scanpass()	(machine_arch_type == MACH_TYPE_SCANPASS)
#else
# define machine_is_scanpass()	(0)
#endif

#ifdef CONFIG_ARCH_EP7312_POOH
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EP7312_POOH
# endif
# define machine_is_ep7312_pooh()	(machine_arch_type == MACH_TYPE_EP7312_POOH)
#else
# define machine_is_ep7312_pooh()	(0)
#endif

#ifdef CONFIG_ARCH_TA7S
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TA7S
# endif
# define machine_is_ta7s()	(machine_arch_type == MACH_TYPE_TA7S)
#else
# define machine_is_ta7s()	(0)
#endif

#ifdef CONFIG_ARCH_TA7V
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TA7V
# endif
# define machine_is_ta7v()	(machine_arch_type == MACH_TYPE_TA7V)
#else
# define machine_is_ta7v()	(0)
#endif

#ifdef CONFIG_SA1100_ICARUS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ICARUS
# endif
# define machine_is_icarus()	(machine_arch_type == MACH_TYPE_ICARUS)
#else
# define machine_is_icarus()	(0)
#endif

#ifdef CONFIG_ARCH_H1900
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H1900
# endif
# define machine_is_h1900()	(machine_arch_type == MACH_TYPE_H1900)
#else
# define machine_is_h1900()	(0)
#endif

#ifdef CONFIG_SA1100_GEMINI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GEMINI
# endif
# define machine_is_gemini()	(machine_arch_type == MACH_TYPE_GEMINI)
#else
# define machine_is_gemini()	(0)
#endif

#ifdef CONFIG_ARCH_AXIM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AXIM
# endif
# define machine_is_axim()	(machine_arch_type == MACH_TYPE_AXIM)
#else
# define machine_is_axim()	(0)
#endif

#ifdef CONFIG_ARCH_AUDIOTRON
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AUDIOTRON
# endif
# define machine_is_audiotron()	(machine_arch_type == MACH_TYPE_AUDIOTRON)
#else
# define machine_is_audiotron()	(0)
#endif

#ifdef CONFIG_ARCH_H2200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H2200
# endif
# define machine_is_h2200()	(machine_arch_type == MACH_TYPE_H2200)
#else
# define machine_is_h2200()	(0)
#endif

#ifdef CONFIG_ARCH_LOOX600
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LOOX600
# endif
# define machine_is_loox600()	(machine_arch_type == MACH_TYPE_LOOX600)
#else
# define machine_is_loox600()	(0)
#endif

#ifdef CONFIG_ARCH_NIOP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NIOP
# endif
# define machine_is_niop()	(machine_arch_type == MACH_TYPE_NIOP)
#else
# define machine_is_niop()	(0)
#endif

#ifdef CONFIG_ARCH_DM310
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DM310
# endif
# define machine_is_dm310()	(machine_arch_type == MACH_TYPE_DM310)
#else
# define machine_is_dm310()	(0)
#endif

#ifdef CONFIG_ARCH_SEEDPXA_C2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SEEDPXA_C2
# endif
# define machine_is_seedpxa_c2()	(machine_arch_type == MACH_TYPE_SEEDPXA_C2)
#else
# define machine_is_seedpxa_c2()	(0)
#endif

#ifdef CONFIG_ARCH_IXP4XX_MGUARD_PCI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXP4XX_MGUARD_PCI
# endif
# define machine_is_ixp4xx_mguardpci()	(machine_arch_type == MACH_TYPE_IXP4XX_MGUARD_PCI)
#else
# define machine_is_ixp4xx_mguardpci()	(0)
#endif

#ifdef CONFIG_ARCH_H1940
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H1940
# endif
# define machine_is_h1940()	(machine_arch_type == MACH_TYPE_H1940)
#else
# define machine_is_h1940()	(0)
#endif

#ifdef CONFIG_ARCH_SCORPIO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SCORPIO
# endif
# define machine_is_scorpio()	(machine_arch_type == MACH_TYPE_SCORPIO)
#else
# define machine_is_scorpio()	(0)
#endif

#ifdef CONFIG_ARCH_VIVA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VIVA
# endif
# define machine_is_viva()	(machine_arch_type == MACH_TYPE_VIVA)
#else
# define machine_is_viva()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_XCARD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_XCARD
# endif
# define machine_is_pxa_xcard()	(machine_arch_type == MACH_TYPE_PXA_XCARD)
#else
# define machine_is_pxa_xcard()	(0)
#endif

#ifdef CONFIG_ARCH_CSB335
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CSB335
# endif
# define machine_is_csb335()	(machine_arch_type == MACH_TYPE_CSB335)
#else
# define machine_is_csb335()	(0)
#endif

#ifdef CONFIG_ARCH_IXRD425
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXRD425
# endif
# define machine_is_ixrd425()	(machine_arch_type == MACH_TYPE_IXRD425)
#else
# define machine_is_ixrd425()	(0)
#endif

#ifdef CONFIG_ARCH_IQ80315
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ80315
# endif
# define machine_is_iq80315()	(machine_arch_type == MACH_TYPE_IQ80315)
#else
# define machine_is_iq80315()	(0)
#endif

#ifdef CONFIG_ARCH_NMP7312
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NMP7312
# endif
# define machine_is_nmp7312()	(machine_arch_type == MACH_TYPE_NMP7312)
#else
# define machine_is_nmp7312()	(0)
#endif

#ifdef CONFIG_ARCH_CX861XX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CX861XX
# endif
# define machine_is_cx861xx()	(machine_arch_type == MACH_TYPE_CX861XX)
#else
# define machine_is_cx861xx()	(0)
#endif

#ifdef CONFIG_ARCH_ENP2611
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ENP2611
# endif
# define machine_is_enp2611()	(machine_arch_type == MACH_TYPE_ENP2611)
#else
# define machine_is_enp2611()	(0)
#endif

#ifdef CONFIG_SA1100_XDA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XDA
# endif
# define machine_is_xda()	(machine_arch_type == MACH_TYPE_XDA)
#else
# define machine_is_xda()	(0)
#endif

#ifdef CONFIG_ARCH_CSIR_IMS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CSIR_IMS
# endif
# define machine_is_csir_ims()	(machine_arch_type == MACH_TYPE_CSIR_IMS)
#else
# define machine_is_csir_ims()	(0)
#endif

#ifdef CONFIG_ARCH_IXP421_DNAEETH
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXP421_DNAEETH
# endif
# define machine_is_ixp421_dnaeeth()	(machine_arch_type == MACH_TYPE_IXP421_DNAEETH)
#else
# define machine_is_ixp421_dnaeeth()	(0)
#endif

#ifdef CONFIG_ARCH_POCKETSERV9200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_POCKETSERV9200
# endif
# define machine_is_pocketserv9200()	(machine_arch_type == MACH_TYPE_POCKETSERV9200)
#else
# define machine_is_pocketserv9200()	(0)
#endif

#ifdef CONFIG_ARCH_TOTO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TOTO
# endif
# define machine_is_toto()	(machine_arch_type == MACH_TYPE_TOTO)
#else
# define machine_is_toto()	(0)
#endif

#ifdef CONFIG_ARCH_S3C2440
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C2440
# endif
# define machine_is_s3c2440()	(machine_arch_type == MACH_TYPE_S3C2440)
#else
# define machine_is_s3c2440()	(0)
#endif

#ifdef CONFIG_ARCH_KS8695P
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KS8695P
# endif
# define machine_is_ks8695p()	(machine_arch_type == MACH_TYPE_KS8695P)
#else
# define machine_is_ks8695p()	(0)
#endif

#ifdef CONFIG_ARCH_SE4000
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SE4000
# endif
# define machine_is_se4000()	(machine_arch_type == MACH_TYPE_SE4000)
#else
# define machine_is_se4000()	(0)
#endif

#ifdef CONFIG_ARCH_QUADRICEPS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_QUADRICEPS
# endif
# define machine_is_quadriceps()	(machine_arch_type == MACH_TYPE_QUADRICEPS)
#else
# define machine_is_quadriceps()	(0)
#endif

#ifdef CONFIG_ARCH_BRONCO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BRONCO
# endif
# define machine_is_bronco()	(machine_arch_type == MACH_TYPE_BRONCO)
#else
# define machine_is_bronco()	(0)
#endif

#ifdef CONFIG_ARCH_ESL_SOFCOMP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ESL_SOFCOMP
# endif
# define machine_is_esl_sofcomp()	(machine_arch_type == MACH_TYPE_ESL_SOFCOMP)
#else
# define machine_is_esl_sofcomp()	(0)
#endif

#ifdef CONFIG_ARCH_S5C7375
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S5C7375
# endif
# define machine_is_s5c7375()	(machine_arch_type == MACH_TYPE_S5C7375)
#else
# define machine_is_s5c7375()	(0)
#endif

#ifdef CONFIG_ARCH_SPEARHEAD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SPEARHEAD
# endif
# define machine_is_spearhead()	(machine_arch_type == MACH_TYPE_SPEARHEAD)
#else
# define machine_is_spearhead()	(0)
#endif

#ifdef CONFIG_ARCH_PANTERA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PANTERA
# endif
# define machine_is_pantera()	(machine_arch_type == MACH_TYPE_PANTERA)
#else
# define machine_is_pantera()	(0)
#endif

#ifdef CONFIG_ARCH_PRAYOGLITE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PRAYOGLITE
# endif
# define machine_is_prayoglite()	(machine_arch_type == MACH_TYPE_PRAYOGLITE)
#else
# define machine_is_prayoglite()	(0)
#endif

#ifdef CONFIG_ARCH_GUMSTIK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GUMSTIK
# endif
# define machine_is_gumstik()	(machine_arch_type == MACH_TYPE_GUMSTIK)
#else
# define machine_is_gumstik()	(0)
#endif

#ifdef CONFIG_ARCH_RCUBE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RCUBE
# endif
# define machine_is_rcube()	(machine_arch_type == MACH_TYPE_RCUBE)
#else
# define machine_is_rcube()	(0)
#endif

#ifdef CONFIG_ARCH_REA_OLV
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_REA_OLV
# endif
# define machine_is_rea_olv()	(machine_arch_type == MACH_TYPE_REA_OLV)
#else
# define machine_is_rea_olv()	(0)
#endif

#ifdef CONFIG_ARCH_PXA_IPHONE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_IPHONE
# endif
# define machine_is_pxa_iphone()	(machine_arch_type == MACH_TYPE_PXA_IPHONE)
#else
# define machine_is_pxa_iphone()	(0)
#endif

#ifdef CONFIG_ARCH_S3C3410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C3410
# endif
# define machine_is_s3c3410()	(machine_arch_type == MACH_TYPE_S3C3410)
#else
# define machine_is_s3c3410()	(0)
#endif

#ifdef CONFIG_ARCH_ESPD_4510B
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ESPD_4510B
# endif
# define machine_is_espd_4510b()	(machine_arch_type == MACH_TYPE_ESPD_4510B)
#else
# define machine_is_espd_4510b()	(0)
#endif

#ifdef CONFIG_ARCH_MP1X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MP1X
# endif
# define machine_is_mp1x()	(machine_arch_type == MACH_TYPE_MP1X)
#else
# define machine_is_mp1x()	(0)
#endif

#ifdef CONFIG_ARCH_AT91RM9200TB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91RM9200TB
# endif
# define machine_is_at91rm9200tb()	(machine_arch_type == MACH_TYPE_AT91RM9200TB)
#else
# define machine_is_at91rm9200tb()	(0)
#endif

#ifdef CONFIG_ARCH_ADSVGX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADSVGX
# endif
# define machine_is_adsvgx()	(machine_arch_type == MACH_TYPE_ADSVGX)
#else
# define machine_is_adsvgx()	(0)
#endif

#ifdef CONFIG_ARCH_OMAP_H2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_H2
# endif
# define machine_is_omap_h2()	(machine_arch_type == MACH_TYPE_OMAP_H2)
#else
# define machine_is_omap_h2()	(0)
#endif

#ifdef CONFIG_ARCH_PELEE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PELEE
# endif
# define machine_is_pelee()	(machine_arch_type == MACH_TYPE_PELEE)
#else
# define machine_is_pelee()	(0)
#endif

#ifdef CONFIG_MACH_E740
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_E740
# endif
# define machine_is_e740()	(machine_arch_type == MACH_TYPE_E740)
#else
# define machine_is_e740()	(0)
#endif

#ifdef CONFIG_ARCH_IQ80331
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IQ80331
# endif
# define machine_is_iq80331()	(machine_arch_type == MACH_TYPE_IQ80331)
#else
# define machine_is_iq80331()	(0)
#endif

#ifdef CONFIG_ARCH_VERSATILE_PB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VERSATILE_PB
# endif
# define machine_is_versatile_pb()	(machine_arch_type == MACH_TYPE_VERSATILE_PB)
#else
# define machine_is_versatile_pb()	(0)
#endif

#ifdef CONFIG_MACH_KEV7A400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KEV7A400
# endif
# define machine_is_kev7a400()	(machine_arch_type == MACH_TYPE_KEV7A400)
#else
# define machine_is_kev7a400()	(0)
#endif

#ifdef CONFIG_MACH_LPD7A400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LPD7A400
# endif
# define machine_is_lpd7a400()	(machine_arch_type == MACH_TYPE_LPD7A400)
#else
# define machine_is_lpd7a400()	(0)
#endif

#ifdef CONFIG_MACH_LPD7A404
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LPD7A404
# endif
# define machine_is_lpd7a404()	(machine_arch_type == MACH_TYPE_LPD7A404)
#else
# define machine_is_lpd7a404()	(0)
#endif

#ifdef CONFIG_ARCH_FUJITSU_CAMELOT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_FUJITSU_CAMELOT
# endif
# define machine_is_fujitsu_camelot()	(machine_arch_type == MACH_TYPE_FUJITSU_CAMELOT)
#else
# define machine_is_fujitsu_camelot()	(0)
#endif

#ifdef CONFIG_ARCH_JANUS2M
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_JANUS2M
# endif
# define machine_is_janus2m()	(machine_arch_type == MACH_TYPE_JANUS2M)
#else
# define machine_is_janus2m()	(0)
#endif

#ifdef CONFIG_MACH_EMBTF
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EMBTF
# endif
# define machine_is_embtf()	(machine_arch_type == MACH_TYPE_EMBTF)
#else
# define machine_is_embtf()	(0)
#endif

#ifdef CONFIG_MACH_HPM
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HPM
# endif
# define machine_is_hpm()	(machine_arch_type == MACH_TYPE_HPM)
#else
# define machine_is_hpm()	(0)
#endif

#ifdef CONFIG_MACH_SMDK2410TK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK2410TK
# endif
# define machine_is_smdk2410tk()	(machine_arch_type == MACH_TYPE_SMDK2410TK)
#else
# define machine_is_smdk2410tk()	(0)
#endif

#ifdef CONFIG_MACH_SMDK2410AJ
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK2410AJ
# endif
# define machine_is_smdk2410aj()	(machine_arch_type == MACH_TYPE_SMDK2410AJ)
#else
# define machine_is_smdk2410aj()	(0)
#endif

#ifdef CONFIG_MACH_STREETRACER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STREETRACER
# endif
# define machine_is_streetracer()	(machine_arch_type == MACH_TYPE_STREETRACER)
#else
# define machine_is_streetracer()	(0)
#endif

#ifdef CONFIG_MACH_EFRAME
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EFRAME
# endif
# define machine_is_eframe()	(machine_arch_type == MACH_TYPE_EFRAME)
#else
# define machine_is_eframe()	(0)
#endif

#ifdef CONFIG_MACH_CSB337
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CSB337
# endif
# define machine_is_csb337()	(machine_arch_type == MACH_TYPE_CSB337)
#else
# define machine_is_csb337()	(0)
#endif

#ifdef CONFIG_MACH_PXA_LARK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_LARK
# endif
# define machine_is_pxa_lark()	(machine_arch_type == MACH_TYPE_PXA_LARK)
#else
# define machine_is_pxa_lark()	(0)
#endif

#ifdef CONFIG_MACH_PNP2110
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PNP2110
# endif
# define machine_is_pxa_pnp2110()	(machine_arch_type == MACH_TYPE_PNP2110)
#else
# define machine_is_pxa_pnp2110()	(0)
#endif

#ifdef CONFIG_MACH_TCC72X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TCC72X
# endif
# define machine_is_tcc72x()	(machine_arch_type == MACH_TYPE_TCC72X)
#else
# define machine_is_tcc72x()	(0)
#endif

#ifdef CONFIG_MACH_ALTAIR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ALTAIR
# endif
# define machine_is_altair()	(machine_arch_type == MACH_TYPE_ALTAIR)
#else
# define machine_is_altair()	(0)
#endif

#ifdef CONFIG_MACH_KC3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KC3
# endif
# define machine_is_kc3()	(machine_arch_type == MACH_TYPE_KC3)
#else
# define machine_is_kc3()	(0)
#endif

#ifdef CONFIG_MACH_SINTEFTD
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SINTEFTD
# endif
# define machine_is_sinteftd()	(machine_arch_type == MACH_TYPE_SINTEFTD)
#else
# define machine_is_sinteftd()	(0)
#endif

#ifdef CONFIG_MACH_MAINSTONE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MAINSTONE
# endif
# define machine_is_mainstone()	(machine_arch_type == MACH_TYPE_MAINSTONE)
#else
# define machine_is_mainstone()	(0)
#endif

#ifdef CONFIG_MACH_ADAY4X
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADAY4X
# endif
# define machine_is_aday4x()	(machine_arch_type == MACH_TYPE_ADAY4X)
#else
# define machine_is_aday4x()	(0)
#endif

#ifdef CONFIG_MACH_LITE300
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_LITE300
# endif
# define machine_is_lite300()	(machine_arch_type == MACH_TYPE_LITE300)
#else
# define machine_is_lite300()	(0)
#endif

#ifdef CONFIG_MACH_S5C7376
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S5C7376
# endif
# define machine_is_s5c7376()	(machine_arch_type == MACH_TYPE_S5C7376)
#else
# define machine_is_s5c7376()	(0)
#endif

#ifdef CONFIG_MACH_MT02
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MT02
# endif
# define machine_is_mt02()	(machine_arch_type == MACH_TYPE_MT02)
#else
# define machine_is_mt02()	(0)
#endif

#ifdef CONFIG_MACH_MPORT3S
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MPORT3S
# endif
# define machine_is_mport3s()	(machine_arch_type == MACH_TYPE_MPORT3S)
#else
# define machine_is_mport3s()	(0)
#endif

#ifdef CONFIG_MACH_RA_ALPHA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RA_ALPHA
# endif
# define machine_is_ra_alpha()	(machine_arch_type == MACH_TYPE_RA_ALPHA)
#else
# define machine_is_ra_alpha()	(0)
#endif

#ifdef CONFIG_MACH_XCEP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XCEP
# endif
# define machine_is_xcep()	(machine_arch_type == MACH_TYPE_XCEP)
#else
# define machine_is_xcep()	(0)
#endif

#ifdef CONFIG_MACH_ARCOM_MERCURY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARCOM_MERCURY
# endif
# define machine_is_arcom_mercury()	(machine_arch_type == MACH_TYPE_ARCOM_MERCURY)
#else
# define machine_is_arcom_mercury()	(0)
#endif

#ifdef CONFIG_MACH_STARGATE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_STARGATE
# endif
# define machine_is_stargate()	(machine_arch_type == MACH_TYPE_STARGATE)
#else
# define machine_is_stargate()	(0)
#endif

#ifdef CONFIG_MACH_ARMADILLOJ
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARMADILLOJ
# endif
# define machine_is_armadilloj()	(machine_arch_type == MACH_TYPE_ARMADILLOJ)
#else
# define machine_is_armadilloj()	(0)
#endif

#ifdef CONFIG_MACH_ELROY_JACK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ELROY_JACK
# endif
# define machine_is_elroy_jack()	(machine_arch_type == MACH_TYPE_ELROY_JACK)
#else
# define machine_is_elroy_jack()	(0)
#endif

#ifdef CONFIG_MACH_BACKEND
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BACKEND
# endif
# define machine_is_backend()	(machine_arch_type == MACH_TYPE_BACKEND)
#else
# define machine_is_backend()	(0)
#endif

#ifdef CONFIG_MACH_S5LINBOX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S5LINBOX
# endif
# define machine_is_s5linbox()	(machine_arch_type == MACH_TYPE_S5LINBOX)
#else
# define machine_is_s5linbox()	(0)
#endif

#ifdef CONFIG_MACH_NOMADIK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NOMADIK
# endif
# define machine_is_nomadik()	(machine_arch_type == MACH_TYPE_NOMADIK)
#else
# define machine_is_nomadik()	(0)
#endif

#ifdef CONFIG_MACH_IA_CPU_9200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IA_CPU_9200
# endif
# define machine_is_ia_cpu_9200()	(machine_arch_type == MACH_TYPE_IA_CPU_9200)
#else
# define machine_is_ia_cpu_9200()	(0)
#endif

#ifdef CONFIG_MACH_AT91_BJA1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91_BJA1
# endif
# define machine_is_at91_bja1()	(machine_arch_type == MACH_TYPE_AT91_BJA1)
#else
# define machine_is_at91_bja1()	(0)
#endif

#ifdef CONFIG_MACH_CORGI
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CORGI
# endif
# define machine_is_corgi()	(machine_arch_type == MACH_TYPE_CORGI)
#else
# define machine_is_corgi()	(0)
#endif

#ifdef CONFIG_MACH_POODLE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_POODLE
# endif
# define machine_is_poodle()	(machine_arch_type == MACH_TYPE_POODLE)
#else
# define machine_is_poodle()	(0)
#endif

#ifdef CONFIG_MACH_TEN
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_TEN
# endif
# define machine_is_ten()	(machine_arch_type == MACH_TYPE_TEN)
#else
# define machine_is_ten()	(0)
#endif

#ifdef CONFIG_MACH_ROVERP5P
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ROVERP5P
# endif
# define machine_is_roverp5p()	(machine_arch_type == MACH_TYPE_ROVERP5P)
#else
# define machine_is_roverp5p()	(0)
#endif

#ifdef CONFIG_MACH_SC2700
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SC2700
# endif
# define machine_is_sc2700()	(machine_arch_type == MACH_TYPE_SC2700)
#else
# define machine_is_sc2700()	(0)
#endif

#ifdef CONFIG_MACH_EX_EAGLE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EX_EAGLE
# endif
# define machine_is_ex_eagle()	(machine_arch_type == MACH_TYPE_EX_EAGLE)
#else
# define machine_is_ex_eagle()	(0)
#endif

#ifdef CONFIG_MACH_NX_PXA12
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NX_PXA12
# endif
# define machine_is_nx_pxa12()	(machine_arch_type == MACH_TYPE_NX_PXA12)
#else
# define machine_is_nx_pxa12()	(0)
#endif

#ifdef CONFIG_MACH_NX_PXA5
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NX_PXA5
# endif
# define machine_is_nx_pxa5()	(machine_arch_type == MACH_TYPE_NX_PXA5)
#else
# define machine_is_nx_pxa5()	(0)
#endif

#ifdef CONFIG_MACH_BLACKBOARD2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BLACKBOARD2
# endif
# define machine_is_blackboard2()	(machine_arch_type == MACH_TYPE_BLACKBOARD2)
#else
# define machine_is_blackboard2()	(0)
#endif

#ifdef CONFIG_MACH_I819
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_I819
# endif
# define machine_is_i819()	(machine_arch_type == MACH_TYPE_I819)
#else
# define machine_is_i819()	(0)
#endif

#ifdef CONFIG_MACH_IXMB995E
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_IXMB995E
# endif
# define machine_is_ixmb995e()	(machine_arch_type == MACH_TYPE_IXMB995E)
#else
# define machine_is_ixmb995e()	(0)
#endif

#ifdef CONFIG_MACH_SKYRIDER
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SKYRIDER
# endif
# define machine_is_skyrider()	(machine_arch_type == MACH_TYPE_SKYRIDER)
#else
# define machine_is_skyrider()	(0)
#endif

#ifdef CONFIG_MACH_SKYHAWK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SKYHAWK
# endif
# define machine_is_skyhawk()	(machine_arch_type == MACH_TYPE_SKYHAWK)
#else
# define machine_is_skyhawk()	(0)
#endif

#ifdef CONFIG_MACH_ENTERPRISE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ENTERPRISE
# endif
# define machine_is_enterprise()	(machine_arch_type == MACH_TYPE_ENTERPRISE)
#else
# define machine_is_enterprise()	(0)
#endif

#ifdef CONFIG_MACH_DEP2410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DEP2410
# endif
# define machine_is_dep2410()	(machine_arch_type == MACH_TYPE_DEP2410)
#else
# define machine_is_dep2410()	(0)
#endif

#ifdef CONFIG_MACH_ARMCORE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ARMCORE
# endif
# define machine_is_armcore()	(machine_arch_type == MACH_TYPE_ARMCORE)
#else
# define machine_is_armcore()	(0)
#endif

#ifdef CONFIG_MACH_HOBBIT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HOBBIT
# endif
# define machine_is_hobbit()	(machine_arch_type == MACH_TYPE_HOBBIT)
#else
# define machine_is_hobbit()	(0)
#endif

#ifdef CONFIG_MACH_H7210
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H7210
# endif
# define machine_is_h7210()	(machine_arch_type == MACH_TYPE_H7210)
#else
# define machine_is_h7210()	(0)
#endif

#ifdef CONFIG_MACH_PXA_NETDCU5
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PXA_NETDCU5
# endif
# define machine_is_pxa_netdcu5()	(machine_arch_type == MACH_TYPE_PXA_NETDCU5)
#else
# define machine_is_pxa_netdcu5()	(0)
#endif

#ifdef CONFIG_MACH_ACC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACC
# endif
# define machine_is_acc()	(machine_arch_type == MACH_TYPE_ACC)
#else
# define machine_is_acc()	(0)
#endif

#ifdef CONFIG_MACH_ESL_SARVA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ESL_SARVA
# endif
# define machine_is_esl_sarva()	(machine_arch_type == MACH_TYPE_ESL_SARVA)
#else
# define machine_is_esl_sarva()	(0)
#endif

#ifdef CONFIG_MACH_XM250
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_XM250
# endif
# define machine_is_xm250()	(machine_arch_type == MACH_TYPE_XM250)
#else
# define machine_is_xm250()	(0)
#endif

#ifdef CONFIG_MACH_T6TC1XB
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_T6TC1XB
# endif
# define machine_is_t6tc1xb()	(machine_arch_type == MACH_TYPE_T6TC1XB)
#else
# define machine_is_t6tc1xb()	(0)
#endif

#ifdef CONFIG_MACH_ESS710
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ESS710
# endif
# define machine_is_ess710()	(machine_arch_type == MACH_TYPE_ESS710)
#else
# define machine_is_ess710()	(0)
#endif

#ifdef CONFIG_MACH_MX3ADS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX3ADS
# endif
# define machine_is_mx3ads()	(machine_arch_type == MACH_TYPE_MX3ADS)
#else
# define machine_is_mx3ads()	(0)
#endif

#ifdef CONFIG_MACH_HIMALAYA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HIMALAYA
# endif
# define machine_is_himalaya()	(machine_arch_type == MACH_TYPE_HIMALAYA)
#else
# define machine_is_himalaya()	(0)
#endif

#ifdef CONFIG_MACH_BOLFENK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BOLFENK
# endif
# define machine_is_bolfenk()	(machine_arch_type == MACH_TYPE_BOLFENK)
#else
# define machine_is_bolfenk()	(0)
#endif

#ifdef CONFIG_MACH_AT91RM9200KR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AT91RM9200KR
# endif
# define machine_is_at91rm9200kr()	(machine_arch_type == MACH_TYPE_AT91RM9200KR)
#else
# define machine_is_at91rm9200kr()	(0)
#endif

#ifdef CONFIG_MACH_EDB9312
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9312
# endif
# define machine_is_edb9312()	(machine_arch_type == MACH_TYPE_EDB9312)
#else
# define machine_is_edb9312()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_GENERIC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_GENERIC
# endif
# define machine_is_omap_generic()	(machine_arch_type == MACH_TYPE_OMAP_GENERIC)
#else
# define machine_is_omap_generic()	(0)
#endif

#ifdef CONFIG_MACH_AXIMX3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_AXIMX3
# endif
# define machine_is_aximx3()	(machine_arch_type == MACH_TYPE_AXIMX3)
#else
# define machine_is_aximx3()	(0)
#endif

#ifdef CONFIG_MACH_EB67XDIP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EB67XDIP
# endif
# define machine_is_eb67xdip()	(machine_arch_type == MACH_TYPE_EB67XDIP)
#else
# define machine_is_eb67xdip()	(0)
#endif

#ifdef CONFIG_MACH_WEBTXS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_WEBTXS
# endif
# define machine_is_webtxs()	(machine_arch_type == MACH_TYPE_WEBTXS)
#else
# define machine_is_webtxs()	(0)
#endif

#ifdef CONFIG_MACH_HAWK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HAWK
# endif
# define machine_is_hawk()	(machine_arch_type == MACH_TYPE_HAWK)
#else
# define machine_is_hawk()	(0)
#endif

#ifdef CONFIG_MACH_CCAT91SBC001
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CCAT91SBC001
# endif
# define machine_is_ccat91sbc001()	(machine_arch_type == MACH_TYPE_CCAT91SBC001)
#else
# define machine_is_ccat91sbc001()	(0)
#endif

#ifdef CONFIG_MACH_EXPRESSO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EXPRESSO
# endif
# define machine_is_expresso()	(machine_arch_type == MACH_TYPE_EXPRESSO)
#else
# define machine_is_expresso()	(0)
#endif

#ifdef CONFIG_MACH_H4000
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_H4000
# endif
# define machine_is_h4000()	(machine_arch_type == MACH_TYPE_H4000)
#else
# define machine_is_h4000()	(0)
#endif

#ifdef CONFIG_MACH_DINO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DINO
# endif
# define machine_is_dino()	(machine_arch_type == MACH_TYPE_DINO)
#else
# define machine_is_dino()	(0)
#endif

#ifdef CONFIG_MACH_ML675K
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ML675K
# endif
# define machine_is_ml675k()	(machine_arch_type == MACH_TYPE_ML675K)
#else
# define machine_is_ml675k()	(0)
#endif

#ifdef CONFIG_MACH_EDB9301
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9301
# endif
# define machine_is_edb9301()	(machine_arch_type == MACH_TYPE_EDB9301)
#else
# define machine_is_edb9301()	(0)
#endif

#ifdef CONFIG_MACH_EDB9315
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_EDB9315
# endif
# define machine_is_edb9315()	(machine_arch_type == MACH_TYPE_EDB9315)
#else
# define machine_is_edb9315()	(0)
#endif

#ifdef CONFIG_MACH_RECIVA_TT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RECIVA_TT
# endif
# define machine_is_reciva_tt()	(machine_arch_type == MACH_TYPE_RECIVA_TT)
#else
# define machine_is_reciva_tt()	(0)
#endif

#ifdef CONFIG_MACH_CSTCB01
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CSTCB01
# endif
# define machine_is_cstcb01()	(machine_arch_type == MACH_TYPE_CSTCB01)
#else
# define machine_is_cstcb01()	(0)
#endif

#ifdef CONFIG_MACH_CSTCB1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CSTCB1
# endif
# define machine_is_cstcb1()	(machine_arch_type == MACH_TYPE_CSTCB1)
#else
# define machine_is_cstcb1()	(0)
#endif

#ifdef CONFIG_MACH_SHADWELL
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SHADWELL
# endif
# define machine_is_shadwell()	(machine_arch_type == MACH_TYPE_SHADWELL)
#else
# define machine_is_shadwell()	(0)
#endif

#ifdef CONFIG_MACH_GOEPEL263
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_GOEPEL263
# endif
# define machine_is_goepel263()	(machine_arch_type == MACH_TYPE_GOEPEL263)
#else
# define machine_is_goepel263()	(0)
#endif

#ifdef CONFIG_MACH_ACQ100
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ACQ100
# endif
# define machine_is_acq100()	(machine_arch_type == MACH_TYPE_ACQ100)
#else
# define machine_is_acq100()	(0)
#endif

#ifdef CONFIG_MACH_MX1FS2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX1FS2
# endif
# define machine_is_mx1fs2()	(machine_arch_type == MACH_TYPE_MX1FS2)
#else
# define machine_is_mx1fs2()	(0)
#endif

#ifdef CONFIG_MACH_HIPTOP_G1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HIPTOP_G1
# endif
# define machine_is_hiptop_g1()	(machine_arch_type == MACH_TYPE_HIPTOP_G1)
#else
# define machine_is_hiptop_g1()	(0)
#endif

#ifdef CONFIG_MACH_SPARKY
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SPARKY
# endif
# define machine_is_sparky()	(machine_arch_type == MACH_TYPE_SPARKY)
#else
# define machine_is_sparky()	(0)
#endif

#ifdef CONFIG_MACH_NS9750
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NS9750
# endif
# define machine_is_ns9750()	(machine_arch_type == MACH_TYPE_NS9750)
#else
# define machine_is_ns9750()	(0)
#endif

#ifdef CONFIG_MACH_PHOENIX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PHOENIX
# endif
# define machine_is_phoenix()	(machine_arch_type == MACH_TYPE_PHOENIX)
#else
# define machine_is_phoenix()	(0)
#endif

#ifdef CONFIG_MACH_VR1000
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_VR1000
# endif
# define machine_is_vr1000()	(machine_arch_type == MACH_TYPE_VR1000)
#else
# define machine_is_vr1000()	(0)
#endif

#ifdef CONFIG_MACH_DEISTERPXA
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DEISTERPXA
# endif
# define machine_is_deisterpxa()	(machine_arch_type == MACH_TYPE_DEISTERPXA)
#else
# define machine_is_deisterpxa()	(0)
#endif

#ifdef CONFIG_MACH_BCM1160
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_BCM1160
# endif
# define machine_is_bcm1160()	(machine_arch_type == MACH_TYPE_BCM1160)
#else
# define machine_is_bcm1160()	(0)
#endif

#ifdef CONFIG_MACH_PCM022
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_PCM022
# endif
# define machine_is_pcm022()	(machine_arch_type == MACH_TYPE_PCM022)
#else
# define machine_is_pcm022()	(0)
#endif

#ifdef CONFIG_MACH_ADSGCX
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ADSGCX
# endif
# define machine_is_adsgcx()	(machine_arch_type == MACH_TYPE_ADSGCX)
#else
# define machine_is_adsgcx()	(0)
#endif

#ifdef CONFIG_MACH_DREADNAUGHT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DREADNAUGHT
# endif
# define machine_is_dreadnaught()	(machine_arch_type == MACH_TYPE_DREADNAUGHT)
#else
# define machine_is_dreadnaught()	(0)
#endif

#ifdef CONFIG_MACH_DM320
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DM320
# endif
# define machine_is_dm320()	(machine_arch_type == MACH_TYPE_DM320)
#else
# define machine_is_dm320()	(0)
#endif

#ifdef CONFIG_MACH_MARKOV
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MARKOV
# endif
# define machine_is_markov()	(machine_arch_type == MACH_TYPE_MARKOV)
#else
# define machine_is_markov()	(0)
#endif

#ifdef CONFIG_MACH_COS7A400
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_COS7A400
# endif
# define machine_is_cos7a400()	(machine_arch_type == MACH_TYPE_COS7A400)
#else
# define machine_is_cos7a400()	(0)
#endif

#ifdef CONFIG_MACH_MILANO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MILANO
# endif
# define machine_is_milano()	(machine_arch_type == MACH_TYPE_MILANO)
#else
# define machine_is_milano()	(0)
#endif

#ifdef CONFIG_MACH_UE9328
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_UE9328
# endif
# define machine_is_ue9328()	(machine_arch_type == MACH_TYPE_UE9328)
#else
# define machine_is_ue9328()	(0)
#endif

#ifdef CONFIG_MACH_UEX255
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_UEX255
# endif
# define machine_is_uex255()	(machine_arch_type == MACH_TYPE_UEX255)
#else
# define machine_is_uex255()	(0)
#endif

#ifdef CONFIG_MACH_UE2410
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_UE2410
# endif
# define machine_is_ue2410()	(machine_arch_type == MACH_TYPE_UE2410)
#else
# define machine_is_ue2410()	(0)
#endif

#ifdef CONFIG_MACH_A620
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_A620
# endif
# define machine_is_a620()	(machine_arch_type == MACH_TYPE_A620)
#else
# define machine_is_a620()	(0)
#endif

#ifdef CONFIG_MACH_OCELOT
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OCELOT
# endif
# define machine_is_ocelot()	(machine_arch_type == MACH_TYPE_OCELOT)
#else
# define machine_is_ocelot()	(0)
#endif

#ifdef CONFIG_MACH_CHEETAH
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CHEETAH
# endif
# define machine_is_cheetah()	(machine_arch_type == MACH_TYPE_CHEETAH)
#else
# define machine_is_cheetah()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_PERSEUS2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_PERSEUS2
# endif
# define machine_is_omap_perseus2()	(machine_arch_type == MACH_TYPE_OMAP_PERSEUS2)
#else
# define machine_is_omap_perseus2()	(0)
#endif

#ifdef CONFIG_MACH_ZVUE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ZVUE
# endif
# define machine_is_zvue()	(machine_arch_type == MACH_TYPE_ZVUE)
#else
# define machine_is_zvue()	(0)
#endif

#ifdef CONFIG_MACH_ROVERP1
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ROVERP1
# endif
# define machine_is_roverp1()	(machine_arch_type == MACH_TYPE_ROVERP1)
#else
# define machine_is_roverp1()	(0)
#endif

#ifdef CONFIG_MACH_ASIDIAL2
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ASIDIAL2
# endif
# define machine_is_asidial2()	(machine_arch_type == MACH_TYPE_ASIDIAL2)
#else
# define machine_is_asidial2()	(0)
#endif

#ifdef CONFIG_MACH_S3C24A0
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C24A0
# endif
# define machine_is_s3c24a0()	(machine_arch_type == MACH_TYPE_S3C24A0)
#else
# define machine_is_s3c24a0()	(0)
#endif

#ifdef CONFIG_MACH_E800
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_E800
# endif
# define machine_is_e800()	(machine_arch_type == MACH_TYPE_E800)
#else
# define machine_is_e800()	(0)
#endif

#ifdef CONFIG_MACH_E750
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_E750
# endif
# define machine_is_e750()	(machine_arch_type == MACH_TYPE_E750)
#else
# define machine_is_e750()	(0)
#endif

#ifdef CONFIG_MACH_S3C5500
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_S3C5500
# endif
# define machine_is_s3c5500()	(machine_arch_type == MACH_TYPE_S3C5500)
#else
# define machine_is_s3c5500()	(0)
#endif

#ifdef CONFIG_MACH_SMDK5500
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SMDK5500
# endif
# define machine_is_smdk5500()	(machine_arch_type == MACH_TYPE_SMDK5500)
#else
# define machine_is_smdk5500()	(0)
#endif

#ifdef CONFIG_MACH_SIGNALSYNC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SIGNALSYNC
# endif
# define machine_is_signalsync()	(machine_arch_type == MACH_TYPE_SIGNALSYNC)
#else
# define machine_is_signalsync()	(0)
#endif

#ifdef CONFIG_MACH_NBC
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NBC
# endif
# define machine_is_nbc()	(machine_arch_type == MACH_TYPE_NBC)
#else
# define machine_is_nbc()	(0)
#endif

#ifdef CONFIG_MACH_ER4525
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_ER4525
# endif
# define machine_is_er4525()	(machine_arch_type == MACH_TYPE_ER4525)
#else
# define machine_is_er4525()	(0)
#endif

#ifdef CONFIG_MACH_NETBOOKPRO
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_NETBOOKPRO
# endif
# define machine_is_netbookpro()	(machine_arch_type == MACH_TYPE_NETBOOKPRO)
#else
# define machine_is_netbookpro()	(0)
#endif

#ifdef CONFIG_MACH_HW90200
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_HW90200
# endif
# define machine_is_hw90200()	(machine_arch_type == MACH_TYPE_HW90200)
#else
# define machine_is_hw90200()	(0)
#endif

#ifdef CONFIG_MACH_CONDOR
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CONDOR
# endif
# define machine_is_condor()	(machine_arch_type == MACH_TYPE_CONDOR)
#else
# define machine_is_condor()	(0)
#endif

#ifdef CONFIG_MACH_CUP
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_CUP
# endif
# define machine_is_cup()	(machine_arch_type == MACH_TYPE_CUP)
#else
# define machine_is_cup()	(0)
#endif

#ifdef CONFIG_MACH_KITE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_KITE
# endif
# define machine_is_kite()	(machine_arch_type == MACH_TYPE_KITE)
#else
# define machine_is_kite()	(0)
#endif

#ifdef CONFIG_MACH_SCB9328
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SCB9328
# endif
# define machine_is_scb9328()	(machine_arch_type == MACH_TYPE_SCB9328)
#else
# define machine_is_scb9328()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_H3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_H3
# endif
# define machine_is_omap_h3()	(machine_arch_type == MACH_TYPE_OMAP_H3)
#else
# define machine_is_omap_h3()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_H4
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_H4
# endif
# define machine_is_omap_h4()	(machine_arch_type == MACH_TYPE_OMAP_H4)
#else
# define machine_is_omap_h4()	(0)
#endif

#ifdef CONFIG_MACH_N10
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_N10
# endif
# define machine_is_n10()	(machine_arch_type == MACH_TYPE_N10)
#else
# define machine_is_n10()	(0)
#endif

#ifdef CONFIG_MACH_MONTAJADE
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MONTAJADE
# endif
# define machine_is_montajade()	(machine_arch_type == MACH_TYPE_MONTAJADE)
#else
# define machine_is_montajade()	(0)
#endif

#ifdef CONFIG_MACH_SG560
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_SG560
# endif
# define machine_is_sg560()	(machine_arch_type == MACH_TYPE_SG560)
#else
# define machine_is_sg560()	(0)
#endif

#ifdef CONFIG_MACH_DP1000
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_DP1000
# endif
# define machine_is_dp1000()	(machine_arch_type == MACH_TYPE_DP1000)
#else
# define machine_is_dp1000()	(0)
#endif

#ifdef CONFIG_MACH_OMAP_OSK
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_OMAP_OSK
# endif
# define machine_is_omap_osk()	(machine_arch_type == MACH_TYPE_OMAP_OSK)
#else
# define machine_is_omap_osk()	(0)
#endif

#ifdef CONFIG_MACH_RG100V3
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_RG100V3
# endif
# define machine_is_rg100v3()	(machine_arch_type == MACH_TYPE_RG100V3)
#else
# define machine_is_rg100v3()	(0)
#endif

#ifdef CONFIG_MACH_MX2ADS
# ifdef machine_arch_type
#  undef machine_arch_type
#  define machine_arch_type	__machine_arch_type
# else
#  define machine_arch_type	MACH_TYPE_MX2ADS
# endif
# define machine_is_mx2ads()	(machine_arch_type == MACH_TYPE_MX2ADS)
#else
# define machine_is_mx2ads()	(0)
#endif

/*
 * These have not yet been registered
 */
/* #define MACH_TYPE_367                  <<not registered>> */
#define machine_is_esl_wireless_tab()	(0)

#ifndef machine_arch_type
#define machine_arch_type	__machine_arch_type
#endif

#endif
